#========================================================================================
# package      DE_EPAGES::AmazonPayments::Hooks::Authorization
# state        private
#========================================================================================
package DE_EPAGES::AmazonPayments::Hooks::Authorization;

use DE_EPAGES::Core::API::PerlTools qw ( ElementOf GetCurrentDateTime );
use DE_EPAGES::AmazonPayments::API::Constants qw (
  AUTHORIZATION_PENDING
  AUTHORIZATION_OPEN
  AUTHORIZATION_DECLINED
  AUTHORIZATION_CLOSED
);
use strict;

#========================================================================================
# function     OnUpdateAuthorization
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnUpdateAuthorization( $hParams );
#----------------------------------------------------------------------------------------
# description  OnUpdateAuthorization is triggered when an authorization from Amazon gets
#               updated.
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                 <li>LineItemPayment      - LineItemPayment       - object
#                 <li>AuthorizationDetails - AuthorizationDetails  - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUpdateAuthorization {
    my ($hParams) = @_;

    my $LineItem      = $hParams->{'LineItemPayment'};
    my $Authorization = $hParams->{'AuthorizationDetails'};

    # ignore any async events unless we're in authorization phase.
    my $CurrentState = $LineItem->get('TransStatus');
    if(defined $CurrentState) {
        return unless ElementOf($CurrentState, (AUTHORIZATION_PENDING, AUTHORIZATION_OPEN, AUTHORIZATION_DECLINED, AUTHORIZATION_CLOSED));
    }

    $LineItem->set( {
            TransStatus  => $Authorization->transStatus,
            TransTimeMod => GetCurrentDateTime(),
        }
    );

    return;
}

1;
