#========================================================================================
# package      DE_EPAGES::AmazonPayments::Hooks::OrderReference
# state        private
#========================================================================================
package DE_EPAGES::AmazonPayments::Hooks::OrderReference;

use DE_EPAGES::Core::API::PerlTools qw ( ElementOf GetCurrentDateTime );
use DE_EPAGES::AmazonPayments::API::Constants qw ( ORDER_CANCELED ORDER_CLOSED );

use strict;

#========================================================================================
# function     OnUpdateOrderReference
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnUpdateOrderReference( $hParams );
#----------------------------------------------------------------------------------------
# description  OnUpdateOrderReference is triggered when an order reference from Amazon gets
#               updated.
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                 <li>LineItemPayment       - LineItemPayment       - object
#                 <li>OrderReferenceDetails - OrderReferenceDetails - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnUpdateOrderReference {
    my ($hParams) = @_;

    my $OrderReferenceDetails = $hParams->{'OrderReferenceDetails'};
    my $LineItem              = $hParams->{'LineItemPayment'};
    my $CurrentState          = $LineItem->get('TransStatus');
    return if defined($CurrentState) and
        ElementOf($CurrentState, (ORDER_CANCELED, ORDER_CLOSED));

    my $OrderStatus = $OrderReferenceDetails->transStatus;
    $LineItem->set({
        TransStatus  => $OrderStatus,
        TransTimeMod => GetCurrentDateTime(),
    });

    my $Order = $LineItem->parent->parent;
    if($OrderStatus eq ORDER_CANCELED) {
        $Order->set({ PendingOn => undef, CancelledOn => GetCurrentDateTime() });
    }

    return;
}

1;
