#========================================================================================
# package      DE_EPAGES::AvaTax::UI::JSON
# base         DE_EPAGES::Presentation::UI::JSON
# state        public
#----------------------------------------------------------------------------------------
# description  Handler for AJAX request to reload a tracking request
#========================================================================================
package DE_EPAGES::AvaTax::UI::JSON;
use base DE_EPAGES::Presentation::UI::JSON;

use DE_EPAGES::Core::API::Log qw ( GetLog LogError );
use DE_EPAGES::Core::API::Error qw ( Error ExistsError GetError );
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf IsA isValid );
use DE_EPAGES::AvaTax::API::AvaTax qw (  Validate UseAvaTax );
use DE_EPAGES::Database::API::Connection qw ( GetCurrentDBHandle );

use DE_EPAGES::AvaTax::API::Constants qw (
    AVATAX_RESULTCODE_Success
    AVATAX_RESULTCODE_Error
    AVATAX_RETURNCODE_NO_ADDRESS_CHECK
    $AVATAX_COUNTRIES_SUPPORTING_ADDRESS_VALIDATION
);

use strict;
#========================================================================================
# function     JSONValidate
# state        public
#----------------------------------------------------------------------------------------
# syntax       JSONValidate( $Servlet );
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet object | object
#----------------------------------------------------------------------------------------
# description
#----------------------------------------------------------------------------------------
# return       $ReturnValue | a html template | String
#========================================================================================

# Pending define returns
sub JSONValidate {
    my $self      = shift;
    my ($Servlet) = @_;
    my $ReturnValue = $self->writeContentOutput( { 'Error' => '1' } );
    my $hReturnAddress;

    my $Address;
    my $Addresslist;
    my $Object = $Servlet->object;
    if (IsA($Object, 'DE_EPAGES::Address::API::Object::Address')) {
        $Address = $Object;
    } elsif (IsA($Object, 'DE_EPAGES::Order::API::Object::Basket') or
             IsA($Object, 'DE_EPAGES::Order::API::Object::CustomerOrder')
    ) {
        $Address = $Object->get('ShippingAddress') // $Object->get('BillingAddress');
    }

    unless ( defined $Address ){
        GetLog()->debug('undefined address for object of class '.$Object->class->alias);
    }

    my $Result;
    my $Form = $Servlet->form;

    my $Shop = $Object->getSite;

    my  $CountryID = $Form->value('CountryID');

    my $UseAvaTax = UseAvaTax($Shop, {'CountryID' => $CountryID});

    if ($UseAvaTax <= 0 ){
        $hReturnAddress->{'returncode'} = AVATAX_RETURNCODE_NO_ADDRESS_CHECK;
        $ReturnValue = $self->writeContentOutput($hReturnAddress);
        return $ReturnValue;
    }

    eval {
        my $TaxMethod = $Shop->get('TaxMethod');

        Error('TaxMethodNotUsableAtStorefront',{
            'TaxMethod' => $TaxMethod->alias,
            'Shop'      => $Shop->alias,
            'Store'     => GetCurrentDBHandle->cacheKey,
        }) unless ($TaxMethod->usableAtStorefront());

        my $IsAddressValidationActivated = $TaxMethod->get('IsAddressValidationActivated');
        my $IsAddressValidationSupported = (defined($CountryID) and
            ElementOf($CountryID, $AVATAX_COUNTRIES_SUPPORTING_ADDRESS_VALIDATION));

        if($IsAddressValidationActivated && $IsAddressValidationSupported) {
            $Result = Validate($Shop, $Address, $Form);
            $Addresslist = $Result->ValidAddressList;
        } else {
            $hReturnAddress->{'returncode'} = AVATAX_RETURNCODE_NO_ADDRESS_CHECK;
            $ReturnValue = $self->writeContentOutput($hReturnAddress);
            return $ReturnValue;
        }
    };
    # error -> validation exception
    if (ExistsError()) {
        my $Error = GetError();
        LogError($Error);

        return $ReturnValue;
    } elsif (! $Result) {
        return $ReturnValue;
    }



    # validation success.
     if ($Result->ResultCode() eq AVATAX_RESULTCODE_Success){
          $hReturnAddress->{'returncode'} = 'ok';
     };

    # validation error
     if ($Result->ResultCode() eq AVATAX_RESULTCODE_Error) {
          $hReturnAddress->{'returncode'} = 'error';
     };

    if (isValid($Addresslist)) {
       foreach my $key (keys %{@$Addresslist[0]}) {
           if ($key eq 'Line1' || $key eq 'Line2' || $key eq 'City' || $key eq 'Region' || $key eq 'PostalCode') {
               my $value = @$Addresslist[0]->{$key};
               $hReturnAddress->{$key} = $value;
           }
        }
    } else {
        $hReturnAddress->{'returncode'} = AVATAX_RETURNCODE_NO_ADDRESS_CHECK;
        $ReturnValue = $self->writeContentOutput($hReturnAddress);
        return $ReturnValue;
    }

     $ReturnValue = $self->writeContentOutput($hReturnAddress);
     return $ReturnValue;
}


1;
