#========================================================================================
# package      DE_EPAGES::Catalog::API::Object::SystemPagerSetting
# base         DE_EPAGES::Shop::API::Object::ShopObject
# state        public
#----------------------------------------------------------------------------------------
# description  Default for PagerSetting. Namly attributes DefaultPageSize, MaxPageSize and
#               StepSize.
#========================================================================================
package DE_EPAGES::Catalog::API::Object::SystemPagerSetting;
use parent DE_EPAGES::Shop::API::Object::ShopObject;

use strict;

use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

#========================================================================================
# function     className
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ClassName = $SystemPagerSetting->className;
#----------------------------------------------------------------------------------------
# description  Returns the class name, used for DAL access.
#----------------------------------------------------------------------------------------
# return       $ClassName | class name | String
#========================================================================================
sub className {'SystemPagerSetting'}

#========================================================================================
# function     validatePageSize
# state        public
#----------------------------------------------------------------------------------------
# syntax       $PagerSetting->validatePageSize( $PageSize );
#----------------------------------------------------------------------------------------
# description  Check if the given $PageSize is valid (element of 'PageSizes'). On failure
#               an Error is thrown.
#========================================================================================
sub validatePageSize {
    my $self       = shift;
    my ($PageSize) = @_;
    my $aPageSizes = $self->get('PageSizes');
    unless ( ElementOf($PageSize, $aPageSizes) ) {
        Error( 'InvalidPageSize', { PageSize => $PageSize, PageSizes => join ', ', @$aPageSizes } );
    }
    return;
}

1;
