#==============================================================================
# package      DE_EPAGES::Core::API::AutoFollowUserAgent
# base         LWP::UserAgent
# state        public
# description  UserAgent which handles redirects and auto-refreshs
# example      my $Browser = DE_EPAGES::Core::API::AutoFollowUserAgent->new;
#               my $Response = $Browser->post( ... )
#==============================================================================
package DE_EPAGES::Core::API::AutoFollowUserAgent;
use base LWP::UserAgent;

use strict;

use HTTP::Request;
use HTTP::Status qw ( HTTP_OK HTTP_MOVED_PERMANENTLY HTTP_FOUND HTTP_TEMPORARY_REDIRECT );
use Test::More;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf trim );

sub new { ## no critic qw(RequireArgUnpacking)
    my $class = shift;

    my $self = $class->SUPER::new(@_);
    return $self;
}

sub request {
    my $self = shift;
    my ($Request) = @_;

    while (1) {
        my $Response = $self->SUPER::request($Request);

        # follow redirects
        if (ElementOf($Response->code, (HTTP_MOVED_PERMANENTLY, HTTP_FOUND, HTTP_TEMPORARY_REDIRECT))) {
            my $URI = URI->new_abs($Response->header('Location'), $Request->uri);

            diag "Redirect to $URI\n";
            $Request = HTTP::Request->new('GET', $URI->as_string);
            $Response = $self->SUPER::request($Request);
            next;
        }

        # auto-refresh
        if ($Response->code eq HTTP_OK and $Response->header('Refresh')) {
            my @Params = map { trim($_) } split /;/, $Response->header('Refresh');
            my $Sleep = shift @Params;
            my $Location = shift @Params;
            $Location =~ s/^URL=//;

            my $URI = URI->new_abs($Location, $Request->uri);

            diag $Response->header('Title'), "\n";
            sleep $Sleep;
            $Request = HTTP::Request->new('GET', $URI->as_string);
            next;
        }

        return $Response;
    }
}

1;

