use strict;
use Test::More tests => 1;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::File qw(GetFileContentLines);

### -> code from Core/API/Object/DateTimeFormatter.pm

# see  https://metacpan.org/pod/DateTime#CLDR-Patterns
# all values here must also be keys in _patternMap of
# DE_EPAGES/Dojo/Data/Public/javascript/epages/localize.js

my $FORMAT_PARSE_MAP = {
    '%{hour_12}'             => '%l',
    '%{hour}'                => '%H',
    '%{day}'                 => '%d',
    '%{month}'               => '%m',
    '%{time_zone_long_name}' => '%z',
    '%{ce_year}'             => '%Y',
    '%y'                     => '%Y',
};

my $CLDR_STRFTIME = [
    qr/G/    => '{era}',
    qr/yyyy/ => 'Y',
    qr/yy/   => 'Y', # always use 4 digits for year
    qr/y/    => 'Y', # always use 4 digits for year
    qr/u/    => 'Y',
    qr/MMMM/ => 'B',
    qr/MMM/  => 'b',
    qr/MM/   => 'm',
    qr/M/    => 'm', # was: {month}
    qr/dd/   => 'd',
    qr/d/    => 'd', # was: {day}
    qr/hh/   => 'l',
    qr/h/    => 'l', # was: {hour_12}
    qr/HH/   => 'H',
    qr/H/    => 'H', # was: {hour}
    qr/mm/   => 'M',
    qr/m/    => 'M', # was: {minute}
    qr/ss/   => 'S',
    qr/s/    => 'S', # was: {second}
    qr/S/    => 'N',
    qr/EEEE/ => 'A',
    qr/cccc/ => 'A',
    qr/E/    => 'a',
    qr/D/    => 'j',
    qr/F/    => '{weekday_of_month}',
    qr/w/    => 'V',
    qr/W/    => '{week_month}',
    qr/a/    => 'p',
    qr/k/    => 'k', # was: {hour_1}
    qr/K/    => 'l', # was: {hour_12_0}
    qr/zzzz/ => 'z', # was: {time_zone_long_name}
    qr/z/    => 'z', # was: {time_zone_long_name}
];

### <- code from Core/API/Object/DateTimeFormatter.pm

sub Main {

    # parse Dojo _patternMap into %DojoStrfTimes

    my $DojoFile = "$ENV{EPAGES_CARTRIDGES}/DE_EPAGES/Dojo/Data/Public/javascript/epages/localize.js";

    my $patternMap = 0;
    my %DojoStrfTimes;
    foreach (@{GetFileContentLines($DojoFile)}) {
        $patternMap = 1 if /^\s*_patternMap\s*:/;
        next unless $patternMap;
        last if /^\s*\}\s*,?\s*$/ and $patternMap;
        s,\s,,g;
        if (/^\s*['"'](%[^'"']+).*/) {
            $DojoStrfTimes{$1} = 1;
        }
    }

    # test if all perl strftime patterns can be found in Dojo _patternMap

    my (%PerlStrfTimes, @MissingStrfTimes);
    map { $PerlStrfTimes{$_} = 1; } values %$FORMAT_PARSE_MAP;
    map { $_ = $CLDR_STRFTIME->[$_]; s,^([^(]),%$1, and $PerlStrfTimes{$_} = 1; }
    (0 .. @$CLDR_STRFTIME-1);
    foreach my $StrfTime (sort keys %PerlStrfTimes) {
        push @MissingStrfTimes, $StrfTime unless $DojoStrfTimes{$StrfTime};
    }
    my $sMissingStrfTimes = join(' ', @MissingStrfTimes);
    $sMissingStrfTimes = 'none' unless $sMissingStrfTimes;
    is($sMissingStrfTimes, 'none', 'check for missing strftime in localize.js');
}

RunScript(Sub=>\&Main, Debug=>1);
