use Test::More tests => 9;
use Test::Exception;

use strict;
use warnings;

use DE_EPAGES::Core::API::FTP;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::Core::API::Script qw( RunScript );
use File::Temp;

##no critic qw(ProhibitInterpolationOfLiterals)
RunScript( Message => 'long', Sub => sub {
        my ( $host, $username, $password ) = ('ftp://epages-software.de','anonymous','');
        my $test_dir = '/repo/epages/LanguagePacks/6.17/';
        my $test_file = 'index.txt';
        my $test_path = $test_dir.$test_file;

        my $ftp;
        my @files;
        my $tmp = File::Temp->new();

        #positive tests
        lives_ok( sub {$ftp = DE_EPAGES::Core::API::FTP->new()}, 'FTP->new' );
        lives_ok( sub {$ftp->connect($host,$username,$password)}, "FTP->connect($host)" );
        lives_ok( sub {$ftp->getFile( $tmp->filename, $test_path)}, "FTP->getFile($host$test_path)" );

        my @filecontent = <$tmp>;
        ok(ElementOf("fr\n", @filecontent), 'FTP: file content validation');
        lives_ok( sub  {@files = $ftp->listFiles($test_dir) }, "FTP->listFiles($host$test_dir)" );
        ok(ElementOf($test_file, @files), 'FTP: file exists in directory');

        #negative tests
        my $nook_host = 'ftp://fakehost';
        throws_ok( sub {$ftp->connect($nook_host,$username,$password)}, qr/FTPError/,"FTP->connect($nook_host)" );
        throws_ok( sub {$ftp->getFile( $tmp->filename, $test_path)}, qr/FTPError/, "FTP->getFile($nook_host$test_path)" );
        throws_ok( sub {$ftp->listFiles($test_dir) }, qr/FTPError/ ,"FTP->listFiles($nook_host$test_dir)" );
});
