#========================================================================================
# package      DE_EPAGES::DHLIntraship::API::Attributes::DHLIntrashipShippingLabel
# base         DE_EPAGES::ExternalShipping::API::Attributes::ShippingLabel
# state        public
# description  Description
#========================================================================================
package DE_EPAGES::DHLIntraship::API::Attributes::DHLIntrashipShippingLabel;
use base DE_EPAGES::ExternalShipping::API::Attributes::ShippingLabel;

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

#========================================================================================
# function     getAttributes
# state        private
#----------------------------------------------------------------------------------------
# syntax       $hValues = getAttributes( $Object, $aNames );
#----------------------------------------------------------------------------------------
# example      # never call getAttributes directly!
#               $Value = $Object->get( $AttributeName );
#----------------------------------------------------------------------------------------
# description  Returns attribute values of an object.
#               Used by <function DE_EPAGES::Object::Object::Object::get>
#               The attributes CanPrintDocument, CanPrintPDF and CanSendPDF are
#               always 0 in this Cartridge
#----------------------------------------------------------------------------------------
# input        $Object | object | object
# input        $aNames | list of attribute names | ref.array
# return       $hInfo | attribute name => value hash | ref.hash
#========================================================================================
sub getAttributes {
   my $self = shift;
   my ($Object, $aNames) = @_;
   my $hInfo = {};
   $hInfo = $self->SUPER::getAttributes($Object, $aNames);
   foreach my $Name (@$aNames) {
       #CanPrintDocument, CanPrintPDF and CanSendPDF are always 0 in this Cartridge
       if ( ElementOf($Name, qw(CanPrintDocument CanPrintPDF CanSendPDF)) ) {
           $hInfo->{$Name} = 0;
       }
   }
   return $hInfo;

}

1;
