#========================================================================================
# package      DE_EPAGES::DHLIntraship::API::ServicePackageOptionConstants::MappingOptionBlacklist
# state        public
#----------------------------------------------------------------------------------------
# description  This is the place DHL Intraship Package Types
#               call t/SettingTest_OpitionsBlacklist.t to validate the %MAPPINGOPTIONBLACKLIST
#========================================================================================
package DE_EPAGES::DHLIntraship::API::ServicePackageOptionConstants::MappingOptionBlacklist;

use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::Core::API::TestParameter qw ( TestString TestArray);

use base Exporter;

use strict;

our @EXPORT_OK = qw (
    %MAPPINGOPTIONBLACKLIST
    CanCombineOptions
);

our %MAPPINGOPTIONBLACKLIST = (
    'Weltpaket' => [
    ],
    'Europaket' => [
    ],
    'Paket' => [
    ],
);

#========================================================================================
# function     CanCombineOptions
# state        public
#----------------------------------------------------------------------------------------
# syntax       CanCombineOptions( $PackageType, $aOptions );
#----------------------------------------------------------------------------------------
# description  Check if for a specific package type the two handover Option can be combined
#----------------------------------------------------------------------------------------
# input        $PackageType | name of package type | String
# input        $aOptions    | array ref of Options to compare  | refarray
# return       $ReturnVariable | boolean if possible | boolean
#========================================================================================
sub CanCombineOptions{
    my ($PackageType, $aOptions) = @_;
    TestString('PackageType', $PackageType);
    TestArray('aOptions', $aOptions);
    Error( 'WrongAmountOfOptions', { Parameter => 'aOptions:'.(scalar @$aOptions) } )
        unless ((scalar @$aOptions) == 2 );

    my $Option1 = $$aOptions[0];
    my $Option2 = $$aOptions[1];

    my $aPackageTypeBlackLists = $MAPPINGOPTIONBLACKLIST{$PackageType};
    if (defined $aPackageTypeBlackLists){
        foreach my $aBlackList (@{$aPackageTypeBlackLists}){
            if ( ElementOf($Option1, $aBlackList) && ElementOf($Option2, $aBlackList) ){
                    return 0;
            }
        }
    }
    return 1;
}
