#========================================================================================
# package DE_EPAGES::DHLIntraship::API::ServicePackageOptionConstants::MappingOptionsOptionGroups
# state   public
#----------------------------------------------------------------------------------------
# description  This is the place DHL Intraship OptionGroups
#========================================================================================
package DE_EPAGES::DHLIntraship::API::ServicePackageOptionConstants::MappingOptionsOptionGroups;
use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

use base Exporter;

use strict;

our @EXPORT_OK = qw (
   %OPTIONGROUPS
   GetOptionGroups
   GetServicePackageOptions
);
our %OPTIONGROUPS = (
    'Other' => [
        'Insurance',
        'Bulkfreight',
    ],
    'Ident' => [
        'Personally',
    ],
);


#========================================================================================
# function     GetOptionGroups
# state        public
#----------------------------------------------------------------------------------------
# syntax       GetOptionGroups( );
#----------------------------------------------------------------------------------------
# description  give all the Service types
#----------------------------------------------------------------------------------------
# return       $ReturnVariable | service types | refarray
#========================================================================================
sub GetOptionGroups{
    return [keys %OPTIONGROUPS];
}
#========================================================================================
# function     GetServicePackageOptions
# state        public
#----------------------------------------------------------------------------------------
# syntax       GetServicePackageOptions( $OptionGroup );
#----------------------------------------------------------------------------------------
# description  if $OptionGroup is not set it gives all Option Group. If the $OptionGroup
#               is set it will return all Option Groups wich belongs to this Service type
#----------------------------------------------------------------------------------------
# input        $OptionGroup   | name of a Option Group | String
# return       $aPackageTypes | package types | refarray
#========================================================================================
sub GetServicePackageOptions{
    my ($OptionGroup) = @_;
    my $aOptions;
    my $aPossibleOptionGroups = GetOptionGroups();
    my $aOptionGroups;
    if (defined $OptionGroup ){
            unless (ElementOf($OptionGroup, $aPossibleOptionGroups)){
                Error( 'NotAValidOptionsType', { Parameter => $OptionGroup } );
            }
            push (@$aOptionGroups, $OptionGroup);
    }else{
        $aOptionGroups = $aPossibleOptionGroups;
    }
    foreach my $Type (@{$aOptionGroups}){
        push(@$aOptions,@{$OPTIONGROUPS{$Type}});
    }
    return $aOptions;
}
1;
