#========================================================================================
# package DE_EPAGES::DHLIntraship::API::ServicePackageOptionConstants::MappingPackageTypeOptions
# state   public
#----------------------------------------------------------------------------------------
# description  This is the place DHL Intraship mapping between Packagetype and Objects
#========================================================================================
package DE_EPAGES::DHLIntraship::API::ServicePackageOptionConstants::MappingPackageTypeOptions;

use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::Core::API::TestParameter qw ( TestString );
use DE_EPAGES::DHLIntraship::API::ServicePackageOptionConstants::MappingOptionsOptionGroups qw (
    GetServicePackageOptions
);

use base Exporter;
use strict;

our @EXPORT_OK = qw (
    %MAPPINGPACKAGETYPEOPTIONS
    GetPackageTypes
    GetOption
);
# If you change the setup do not forget to call the setupPO test. It will check if this setup is valid
our %MAPPINGPACKAGETYPEOPTIONS = (
        'Weltpaket' => {
            'Insurance'     => 1,
            'Bulkfreight'   => 1,
        },
        'Europaket' => {
            'Insurance'     => 1,
        },
        'Paket' => {
            'Insurance'     => 1,
            'Personally'    => 1,
            'Bulkfreight'   => 1,
        },

    );
#========================================================================================
# function     GetPackageTypes
# state        public
#----------------------------------------------------------------------------------------
# syntax       GetPackageTypes( );
#----------------------------------------------------------------------------------------
# description  give all the package types
#----------------------------------------------------------------------------------------
# return       $ReturnVariable | package types | refarray
#========================================================================================
sub GetPackageTypes{
    my $aPackageTypes = [keys %MAPPINGPACKAGETYPEOPTIONS];
    return [sort(@$aPackageTypes)];
}
#========================================================================================
# function     GetOption
# state        public
#----------------------------------------------------------------------------------------
# syntax       GetOption( $PackageType, $OptionName );
#----------------------------------------------------------------------------------------
# description  get the option to a specific Packagetype
#----------------------------------------------------------------------------------------
# input        $PackageType | name of a Packagetype | String
# input        $OptionName  | name of a $Option     | String
# return       $ReturnVariable | 1 or a specific number if the option is available  | integer
#========================================================================================
sub GetOption{
    my ($PackageType, $OptionName) = @_;
    TestString('PackageType', $PackageType);
    TestString('OptionName', $OptionName);
    my $aPackageTypes = GetPackageTypes();
    return unless (ElementOf($PackageType, $aPackageTypes));
    my $aOptions = _GetServicePackageOptionsWrapper();
    return unless (ElementOf($OptionName, $aOptions));
    return $MAPPINGPACKAGETYPEOPTIONS{$PackageType}->{$OptionName};
}

#========================================================================================
# function     _GetServicePackageOptionsWrapper
# state        private
#----------------------------------------------------------------------------------------
# syntax       _GetServicePackageOptionsWrapper( );
#----------------------------------------------------------------------------------------
# description  Because of the Export of public functions is to static in perl,
#               the GetServicePackageOptions function will be wrapped in a local private function for mocking
#----------------------------------------------------------------------------------------
# return       $ReturnVariable | ReturnDescription | ReturnType_boolean_integer_String_object_refhash_refarray
#========================================================================================
sub _GetServicePackageOptionsWrapper {
    return GetServicePackageOptions();
}
