#========================================================================================
# package      DE_EPAGES::DHLIntraship::API::ServicePackageOptionConstants::MappingServiceTypePackageType
# state        public
#----------------------------------------------------------------------------------------
# description  This is the place DHL Intraship Package Types
#========================================================================================
package DE_EPAGES::DHLIntraship::API::ServicePackageOptionConstants::MappingServiceTypePackageType;
use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

use base Exporter;

use strict;

our @EXPORT_OK = qw (
   %MAPPINGSERVICETYPEPACKAGETYPE
   GetServiceTypes
   GetPackageTypes
);
our %MAPPINGSERVICETYPEPACKAGETYPE = (
    'DD' => [
        'Paket',
        'Europaket',
        'Weltpaket',
    ],
);

#========================================================================================
# function     GetServiceTypes
# state        public
#----------------------------------------------------------------------------------------
# syntax       GetServiceTypes( );
#----------------------------------------------------------------------------------------
# description  give all the Service types
#----------------------------------------------------------------------------------------
# return       $ReturnVariable | service types | refarray
#========================================================================================
sub GetServiceTypes{
    return [keys %MAPPINGSERVICETYPEPACKAGETYPE];
}

#========================================================================================
# function     GetPackageTypes
# state        public
#----------------------------------------------------------------------------------------
# syntax       GetPackageTypes( $ServiceType );
#----------------------------------------------------------------------------------------
# description  if $ServiceType is not set it gives all package types. If the $ServiceType
#               is set it will return all package types wich belongs to this Service type
#----------------------------------------------------------------------------------------
# input        $ServiceType   | name of a service type | String
# return       $aPackageTypes | package types | refarray
#========================================================================================
sub GetPackageTypes{
    my ($ServiceType) = @_;
    my $aPackageTypes;
    my $aPossibleServiceTypes = GetServiceTypes();
    my $aServiceTypes;
    if (defined $ServiceType ){
            unless (ElementOf($ServiceType, $aPossibleServiceTypes)){
                Error( 'NotAValidServiceType', { Parameter => $ServiceType } );
            }
            push ( @$aServiceTypes, $ServiceType );
    }else{
        $aServiceTypes = $aPossibleServiceTypes;
    }
    foreach my $Type ( @{$aServiceTypes} ){
        push( @$aPackageTypes, @{$MAPPINGSERVICETYPEPACKAGETYPE{$Type}} );
    }
    return $aPackageTypes;
}
1;
