#========================================================================================
# package      DE_EPAGES::DHLIntraship::UI::ShippingFulfillmentMethod
# state        private
#----------------------------------------------------------------------------------------
# description  User interface for ShippingFulfillmentMethodDHLIntraship,
#
#========================================================================================
package DE_EPAGES::DHLIntraship::UI::ShippingFulfillmentMethodDHLIntraship;
use base DE_EPAGES::Presentation::UI::Object;

use DE_EPAGES::DHLIntraship::API::Constants qw ( $GET_MANIFEST_OPERATION_IS_VALID );
use DE_EPAGES::DHLIntraship::API::SOAP::CredentialsValidationRequest;
use DE_EPAGES::DHLIntraship::API::SOAP::CredentialsValidationResponse;
use DE_EPAGES::DHLIntraship::API::SOAP::WebServiceClient;
use DE_EPAGES::DHLIntraship::API::Tools;

use strict;


#========================================================================================
# function     ViewSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       ViewSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  View the settings of the shipping fulfillment method
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet object | object
#========================================================================================
sub ViewSettings {
    my $self = shift;
    my ($Servlet) = @_;

    $self->SUPER::View($Servlet);
}

#========================================================================================
# function     SaveSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       SaveSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  Save the settings of the shipping fulfillment method
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet object | object
#========================================================================================
sub SaveSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $ShippingFulfillmentMethod = $Servlet->object();
    my $Form = $Servlet->form();
    $Form->form($ShippingFulfillmentMethod, 'FulfillmentMethod');

    my $MethodName = (caller(0))[3];
    DE_EPAGES::DHLIntraship::API::Tools->LogShopContext(
            $ShippingFulfillmentMethod,
            $MethodName,
            sub {
                if ($self->_areValidCredentials($Form, $ShippingFulfillmentMethod)) {
                    $self->SUPER::Save($Servlet);
                } else {
                    $Form->executeFormError({
                        'Form'     => 'FulfillmentMethod',
                        'Name'     => 'InvalidCredentials',
                        'Reason'   => 'InvalidCredentials',
                    });
                }
            }
    );

    return;
}

#========================================================================================
# function     _areValidCredentials
# state        private
#----------------------------------------------------------------------------------------
# syntax       $areValid = $self->_areValidCredentials( $Form );
#----------------------------------------------------------------------------------------
# description  Validate provided credentials against web service
#----------------------------------------------------------------------------------------
# input        $Form | servlet object | object
# input        $Form | servlet object | object
# return       $areValid | credentials are successfully validated | boolean
#========================================================================================
sub _areValidCredentials {
    my $self = shift;
    my ($Form, $ShippingFulfillmentMethod) = @_;

    my $IsTestMode = $Form->value('IsInTestMode');

    my $CredentialsValidationRequestBuilder = DE_EPAGES::DHLIntraship::API::SOAP::CredentialsValidationRequest->new();
    my $CredentialsValidationResponseParser = DE_EPAGES::DHLIntraship::API::SOAP::CredentialsValidationResponse->new();
    my $DHLWSClient = DE_EPAGES::DHLIntraship::API::SOAP::WebServiceClient->new(
            $CredentialsValidationRequestBuilder,
            $CredentialsValidationResponseParser,
            $IsTestMode
    );

    my $userToTest = $Form->value('WebserviceUsername');
    my $signatureToTest = $self->_getUnencriptedPassword($Form, $ShippingFulfillmentMethod);

    my $hParsedResponse = $DHLWSClient->getManifest(
            {
                'user' => $userToTest,
                'signature' => $signatureToTest
            }
    );

    return ( $hParsedResponse->{'login'} eq $GET_MANIFEST_OPERATION_IS_VALID ) ? 1 : 0;
}

#========================================================================================
sub _getUnencriptedPassword {
    my $self = shift;
    my ($Form, $ShippingFulfillmentMethod) = @_;

    if ( $Form->value('WebservicePassword') =~ /^\*+$/) {
        return $ShippingFulfillmentMethod->get('WebservicePassword');
    } else {
        return $Form->value('WebservicePassword');
    }
}

1;
