#==============================================================================
# package      DE_EPAGES::Diagnostics::UI::TLECompiler
# state        private
#==============================================================================
package DE_EPAGES::Diagnostics::UI::TLECompiler;

use strict;
use DE_EPAGES::Presentation::API::Template qw (GetTLEProcessor);
use DE_EPAGES::Object::API::Factory qw( LoadRootObject );
use DE_EPAGES::Diagnostics::API::HelpCenter qw( GetApiInfoFromDocRoot );
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

#==============================================================================
# Common initialization for all event handlers
#==============================================================================

sub new {##no critic (RequireArgUnpacking)
    my $class = shift;
    my $self = bless { @_ }, $class;

    $self->{TemplateDir} = "$ENV{EPAGES_CARTRIDGES}/DE_EPAGES/Diagnostics/Templates";

    return $self;
}

#==============================================================================
# TLE variables
#==============================================================================
sub handlerLoop {
    my $self = shift;
    my ($hHandlers) = @_;

    my @Loop;
    foreach my $Name (sort keys %$hHandlers) {
        my $Package = $hHandlers->{$Name};
        $Package =~ s/=.*//;
        # example: http://helpcenter.epages.com/Doc/ver_6_11_3/epages/API/DE_EPAGES/TLE/API/LoopHandler.pm.html
        my $APIDocu = "$Package.pm.html";
        $APIDocu =~ s/::/\//g;

        my $DocRoot = LoadRootObject()->get('DocRoot');
        my $aKnownAPIDocs = GetApiInfoFromDocRoot($DocRoot);
        my $APIDocuURL = "$DocRoot/API/$APIDocu";

        push @Loop, {
            'Name' => $Name,
            'Package' => $Package,
            'APIDocu' => "$APIDocuURL#$Name",
            'ExistsDocu' => ElementOf($APIDocu, $aKnownAPIDocs),
        };
    }

    return \@Loop;
}

sub namedFunctions {
    my $self = shift;
    my ($Processor) = @_;

    return $self->handlerLoop( $Processor->{'NamedFunctionHandler'} );
}

sub namedFormats {
    my $self = shift;
    my ($Processor) = @_;

    return $self->handlerLoop( $Processor->{'NamedFormatHandler'} );
}

sub namedVariables {
    my $self = shift;
    my ($Processor) = @_;

    return $self->handlerLoop( $Processor->{'NamedVariableHandler'} );
}

sub ViewTLEFunctions {
    my $self = shift;
    my ($Servlet) = @_;

    my $TLEProcessor = GetTLEProcessor();

    $Servlet->vars( 'TemplateFile', "$self->{TemplateDir}/TLEFunctions.html" );
    $Servlet->vars( 'NamedFunctionHandler', $self->namedFunctions($TLEProcessor));
    $Servlet->vars( 'NamedFormatHandler', $self->namedFormats($TLEProcessor));
    $Servlet->vars( 'NamedVariableHandler', $self->namedVariables($TLEProcessor));
    return;
}

1;
