#==============================================================================
# package      DE_EPAGES::Diagnostics::UI::Trigger
# state        private
#==============================================================================
package DE_EPAGES::Diagnostics::UI::Trigger;

use strict;
use DE_EPAGES::Object::API::Factory qw( LoadRootObject );
use DE_EPAGES::Trigger::API::Table::Hook qw( GetAllInfoHooks GetInfoHook );
use DE_EPAGES::Trigger::API::Table::HookFunction qw( GetInfoHookFunctionsByHookID );
use DE_EPAGES::Diagnostics::API::HelpCenter qw( GetApiInfoFromDocRoot );
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

#==============================================================================
# Common initialization for all event handlers
#==============================================================================

sub new {
    my $class = shift;
    my $self = bless {}, $class;

    $self->{TemplateDir} = "$ENV{EPAGES_CARTRIDGES}/DE_EPAGES/Diagnostics/Templates";

    return $self;
}

#==============================================================================
# TLE variables
#==============================================================================

sub HookFunctionsLoop {
    my ($HookID) = @_;

    return [
        map { HookFunctionVars( $_ ) }
        sort { $a->{'OrderNo'} <=> $b->{'OrderNo'} }
        @{GetInfoHookFunctionsByHookID( $HookID )}
    ];
}

sub HookVars {
    my ($hHook) = @_;

    my $HookID = $hHook->{HookID};

    return {
        ( map { ( "Hook$_" => $hHook->{$_} ) } %$hHook ),
        HookID => $HookID,
        HookFunctions => sub { HookFunctionsLoop( $HookID ) },
    }
}

sub HooksLoop {

    return [
        map { HookVars($_) }
        sort { $a->{Name} cmp $b->{Name} }
        @{GetAllInfoHooks()}
    ];
}

sub HookFunctionVars {
    my ($hHookFunction) = @_;

    my $HookFunctionID = $hHookFunction->{HookFunctionID};

    # build link for API documentation
    # example: http://helpcenter.epages.com/Doc/ver_6_11_3/epages/API/DE_EPAGES/Newsletter/Hooks/User.pm.html#OnAfterUpdateUser
    my $FunctionName = $hHookFunction->{'FunctionName'};
    my ($Package, $Name);
    if ($FunctionName =~ s/(.*)::(\w+)$//) {
        $Package = $1;
        $Name = $2;
    }
    my $APIDocu = "$Package.pm.html";
    $APIDocu =~ s/::/\//g;

    my $DocRoot = LoadRootObject()->get('DocRoot');
    my $aKnownAPIDocs = GetApiInfoFromDocRoot($DocRoot);
    my $APIDocuURL = "$DocRoot/API/$APIDocu";

    return {
        ( map { ( "HookFunction$_" => $hHookFunction->{$_} ) } %$hHookFunction ),
        HookFunctionID => $HookFunctionID,
        APIDocu => "$APIDocuURL#$Name",
        ExistsDocu => ElementOf($APIDocu, $aKnownAPIDocs),
    }
}

#==============================================================================
# Event handlers
#==============================================================================

sub ViewAllHooks {
    my $self = shift;
    my ($Servlet) = @_;

    $Servlet->vars( 'Hooks', HooksLoop() );
    $Servlet->vars( 'TemplateFile', "$self->{TemplateDir}/Hooks.html" );
}

sub ViewHook {
    my $self = shift;
    my ($Servlet) = @_;

    my $HookID = $Servlet->params( 'HookID' );
    my $hHookVars = HookVars( GetInfoHook( $HookID ) );
    $Servlet->vars( $_, $hHookVars->{$_} ) foreach keys %$hHookVars;
    $Servlet->vars( 'TemplateFile', "$self->{TemplateDir}/Hook.html" );
}

1;
