#========================================================================================
# package      DE_EPAGES::DocdataPay::API::Attributes::Shop
# state        private
# description  Implements the attributes Shop.Categories
#========================================================================================
package DE_EPAGES::DocdataPay::API::Attributes::Shop;
use base qw( DE_EPAGES::Object::API::BaseAttribute Exporter );

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

our @EXPORT_OK = qw ( AreMandatoryShippingFieldsSet );

sub getAttributes {
    shift;
    my ( $Shop, $aNames, $LanguageID ) = @_;

    my %Values;
    foreach my $Name (@$aNames) {
        if ( $Name eq 'DocdataPayAreMandatoryShippingFieldsSet' ) {
            $Values{$Name} = AreMandatoryShippingFieldsSet($Shop);
        }
    }
    return \%Values;
}

#========================================================================================
# function     AreMandatoryShippingFieldsSet
# state        public
#----------------------------------------------------------------------------------------
# syntax       $IsAllowed = AreMandatoryShippingFieldsSet($Shop);
# example      my $IsAllowed  = AreMandatoryShippingFieldsSet($Shop);
#----------------------------------------------------------------------------------------
# description  checks all required fields are mandatory in the shop
#----------------------------------------------------------------------------------------
# input        #Shop | shop object | object
# return       #Value | 1 or 0 | boolean
#========================================================================================
sub AreMandatoryShippingFieldsSet {
    my ($Shop) = @_;
    my @ShippingAddressMandatoryFields = split( /\,/, $Shop->get('ShippingAddressSetMandatoryFields') );
    foreach my $field (qw( FirstName LastName Street Zipcode City EMail CountryID )) {
        return 0 unless ElementOf($field, @ShippingAddressMandatoryFields);
    }
    return 1;
}

1;
