#========================================================================================
# package      DE_EPAGES::Envialia::API::Attributes::ShippingLabel
# state        private
# description  Attribute interface for ShippingLabel.
#========================================================================================
package DE_EPAGES::Envialia::API::Attributes::ShippingLabel;
use base qw( DE_EPAGES::ExternalShipping::API::Attributes::ShippingLabel );

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

#========================================================================================
# function     getAttributes
# state        private
#----------------------------------------------------------------------------------------
# syntax       $hValues = getAttributes( $Object, $aNames );
#----------------------------------------------------------------------------------------
# example      # never call getAttributes directly!
#               $Value = $Object->get( $AttributeName );
#----------------------------------------------------------------------------------------
# description  Returns attribute values of an object.
#               Used by <function DE_EPAGES::Object::Object::Object::get>
#               The attributes CanPrintDocument and CanSendPDF are
#               always 0 in this Cartridge
#----------------------------------------------------------------------------------------
# input        $Object | object | object
# input        $aNames | list of attribute names | ref.array
# return       $hInfo | attribute name => value hash | ref.hash
#========================================================================================
sub getAttributes {
    my $self = shift;
    my ($Object, $aNames) = @_;
    my $hInfo = {};
    foreach my $Name (@$aNames) {
        if ( ElementOf($Name, qw( CanPrintDocument CanSendPDF )) ) {
            #EPG-23489 - This cartridge can only print PDF of the shipping label
            $hInfo->{$Name} = 0;
        }
    }
    return $hInfo;
}

1;
