#========================================================================================
# package      DE_EPAGES::ExternalShipping::API::Attributes::ShippingLabel
# state        private
# description  Attribute interface for ShippingLabel.
#========================================================================================
package DE_EPAGES::ExternalShipping::API::Attributes::ShippingLabel;
use base qw( DE_EPAGES::Object::API::BaseAttribute );


use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

sub getAttributes {
    my $self = shift;
    my ($Object, $aNames) = @_;
    my $hInfo = {};
    foreach my $Name (@$aNames) {
        if ( $Name eq 'AddressID' ) {
            if ( $Object->existsChild('Address') ) {
                $hInfo->{$Name} = $Object->child('Address')->id;
            } else {
                my $Address = $Object->get('Order')->get('ShippingAddress');
                $Address = $Object->get('Order')->get('BillingAddress') unless defined $Address;
                $hInfo->{$Name} = $Address->id;
            }
        } elsif ( $Name eq 'NextLabelID' ) {
            my $Transaction = $Object->get('ShippingTransaction');
            if ($Transaction) {
                my $aLabels = $Transaction->get('ShippingLabels');
                my $ObjectID = $Object->id;
                for ( my $i=0; $i < (scalar @{$aLabels} - 1); ++$i) {
                    my $CurrentLabel = $aLabels->[$i];
                    if ($CurrentLabel->id eq $ObjectID) {
                        $hInfo->{$Name} = $aLabels->[$i+1]->id;
                        last;
                    }
                }
            }
        } elsif ( $Name eq 'PreviousLabelID' ) {
            my $Transaction = $Object->get('ShippingTransaction');
            if ($Transaction) {
                my $aLabels = $Transaction->get('ShippingLabels');
                my $ObjectID = $Object->id;
                for ( my $i=1; $i < (scalar @{$aLabels}); ++$i) {
                    my $CurrentLabel = $aLabels->[$i];
                    if ($CurrentLabel->id eq $ObjectID) {
                        $hInfo->{$Name} = $aLabels->[$i-1]->id;
                        last;
                    }
                }
            }
        } elsif ( $Name eq 'IsValid' ) {
            $hInfo->{$Name} = $Object->isValid();
        } elsif ( ElementOf($Name, qw( CanPrintDocument CanPrintPDF CanSendPDF )) ) {
            $hInfo->{$Name} = $Object->get('Issued');
        }
    }
    return $hInfo;
}

1;
