use Test::More;

use DE_EPAGES::Core::API::File qw ( GetFileContent );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Installer::API::Object::PatchCodeGenerator;
use strict;

sub Main {
    my $CG = DE_EPAGES::Installer::API::Object::PatchCodeGenerator->new();
    my (%Tests, $Expected, $Result);

    %Tests = (
        'index_control_01_droppedindex' => 'dropped index',
        'index_control_01_droppedindex_twice' => 'dropped two indeces',
        );

    for (sort keys %Tests) {
        $Result = $CG->getCodeForDiffInSQLFiles({'index_ref_01.sql' => "$_.sql"}, 'Sybase');
        $Expected = GetFileContent("$_.out");
        is(OnlyDbiStatements($Result), OnlyDbiStatements($$Expected), $Tests{$_});
    }

    %Tests = (
        'index_control_01_addedindex' => 'added index (default sort)',
        'index_control_01_addedindex_asc' => 'added index (ASC sort)',
        'index_control_01_addedindex_desc' => 'added index (DESC sort)',
        'index_control_01_addedindex_multicolumn' => 'added index on two columns',
        'index_control_01_changedindex' => 'changed index sort order',
        'index_control_01_addedindex_unique' => 'added unique index',
        'index_control_01_addedindex_unique_clustered' => 'added unique clustered index',
        'index_control_01_addedindex_nonclustered' => 'added nonclustered index',
        'index_control_01_changedindex_twice' => 'changed two indeces: sort order and clustered to default',
        'index_ref_01' => 'no changes',
        );

    for (sort keys %Tests) {
        $Result = $CG->getCodeForDiffInSQLFiles({'index_ref_01.sql' => "$_.sql"}, 'Sybase');
        $Expected = GetFileContent("$_.out");
        is($Result, $$Expected, $Tests{$_});
    }

    %Tests = (
        'addcolumn' => 'different variation of add table column for mysql',
        'changedview' => 'changed view for mysql',
        );

    for (sort keys %Tests) {
        $Result = $CG->getCodeForDiffInSQLFiles({"${_}_old.sql" => "${_}_new.sql"}, 'mysql');
        $Expected = GetFileContent("$_.out");
        is($Result, $$Expected, $Tests{$_});
    }
}

sub OnlyDbiStatements {
    my ($string) = @_;
    my @matches = ($string =~ m/(\$dbi->.*;)/gm);
    $string = join "\n", @matches;
    $string =~ s/\s//g;
    return $string;
}

RunScript( Sub => \&Main );

done_testing();

1;
