use strict;

use DE_EPAGES::JQuery::API::DictionaryConverter qw (
    ConvertMainDictionary
    ConvertCartridgeDictionary
    ConvertSubDictionary
);

use Getopt::Long;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Config qw( StoreType BUStoreTypes );
use DE_EPAGES::XML::API::XML::CartridgeInstallerImportHandler qw( GetCartridges );

sub Main {
    local $| = 1;

    my ($Help, $StoreType, $Version, $Cartridge, $StoreName);

    GetOptions(
        'help'          => \$Help,
        'storetype=s'   => \$StoreType,
        'version=s'     => \$Version,
        'cartridge=s'   => \$Cartridge,
        'storename=s'   => \$StoreName,
    );

    usage() if $Help;
    usage('The store type is not defined.') if !$StoreType && !$StoreName;
    usage('The store type version number is not defined.') unless $Version;

    # backward compatibility mode
    my $aStoreTypes = $StoreType ? [split(/ /, $StoreType)]
        : [map { StoreType($_) } split(/ /, $StoreName)];

    my $haCartridges = GetCartridges();
    my %Info = ( 'version' => $Version );
    my $time1 = time;

    foreach ( @{BUStoreTypes()} ) {
        next unless ElementOf('all', $aStoreTypes) or ElementOf($_, $aStoreTypes);
        $Info{'storetype'} = $_;
        ConvertMainDictionary(\%Info);

        my $aCartridges = $Cartridge eq 'ALL' ? $haCartridges->{$_} : [ $Cartridge ];
        foreach my $Cartridge (@$aCartridges){
            $Info{'cartridge'} = $Cartridge;
            ConvertCartridgeDictionary(\%Info);
            ConvertSubDictionary(\%Info);
        }
    }
    printf "need %.1f seconds%30s\n", time-$time1, '';
}

sub usage() {
    my ($Msg) = @_;
    print "$Msg\n\n" if $Msg;
    print <<END_USAGE;
Description:
    This script converts dictionary files from xml to json.

Usage:
    perl $0 -storetype -version -cartridge

options:
    -storetype   list of store type, if set to "all" all store types will be affected
    -version     epages version number
    -cartridge   cartridges to process, if set to "ALL" all cartridges will be affected

flags:
    -help        show the command line options

Example:
    perl $0 -storetype all -version 6.11.0 -cartridge ALL
    perl $0 -storetype Store -version 6.11.0 -cartridge DE_EPAGES::Design
    perl $0 -storetype "Site Store" -version 6.11.0 -cartridge ALL
END_USAGE
    exit 2;
}

RunScript(
    'Sub' => \&Main
);
