#========================================================================================
# package      DE_EPAGES::Mediafinanz::API::Object::MfBuergelConCheck
# state        public
# base         DE_EPAGES::CreditCheck::API::Object::MfBuergelConCheck
# description  object interface for MfBuergelConCheck.
#========================================================================================
package DE_EPAGES::Mediafinanz::API::Object::MfBuergelConCheck;
use base DE_EPAGES::CreditCheck::API::Object::CreditCheckAgencyConfigDescending;

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::Mediafinanz::API::Buergel qw (GetConCheckScore GetConCheckInternationalScore);
use DE_EPAGES::Mediafinanz::API::Constants qw ( @NON_GERMAN_COUNTRIES );

#========================================================================================
# function     className
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ClassName = $MfBuergelConCheck->className;
#----------------------------------------------------------------------------------------
# description  Returns the class name, used for DAL access.
#----------------------------------------------------------------------------------------
# return       $ClassName | class name | String
#========================================================================================
sub className  { 'MfBuergelConCheck' }

#========================================================================================
sub getScore {
    my $self = shift;
    my ($Basket) = @_;

    my $score;
    my $Country = $Basket->get('BillingAddress')->get('Country')->{'Code2'};

    if( ElementOf($Country, @NON_GERMAN_COUNTRIES) ) {
        $score = GetConCheckInternationalScore($Country, $self->get('CreditCheckProviderConfig')->get('PartnerCustomerID'),
        $Basket);
    } else {
        $score = GetConCheckScore(
        $self->get('CreditCheckProviderConfig')->get('PartnerCustomerID'),
        $Basket);
    }

    $score = undef if (defined($score) && $score == 0); # 0 means can not be evaluated
    return $score;
}

1;
