#========================================================================================
# package      DE_EPAGES::Mollie::t::unit::PaymentRequest
# base         DE_EPAGES::Database::API::Test
# state        private
# description  API/Object/PaymentRequest.pm unit test
#========================================================================================
package DE_EPAGES::Mollie::t::PaymentRequest;
use base DE_EPAGES::Database::API::Test;

use DE_EPAGES::Mollie::API::PaymentRequest;
use DE_EPAGES::Test::Mock::EpagesObject;
use HTTP::Response;
use HTTP::Status qw ( :constants :is status_message );
use Test::MockObject;
use Test::Exception;
use Test::More;

use strict;

## no critic qw(ProhibitLongLines)

#========================================================================================
sub test {
    my $self = shift;
    $self->createRequest_positive_test();
    $self->createRequest_negative_test();
    done_testing();
}

#========================================================================================
sub init {
    my $self = shift;

    my $Shop = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {
        GUID => 'shopGUID'
    });

    $self->{'Client'} = DE_EPAGES::Mollie::API::PaymentRequest->create( {
            BaseURL  => 'http://localhost:8088/rs/',
            Shop     => $Shop,
            ShopType => 'eCom100',
            Locale   => 'en_GB',
            BusinessUnit => 'blabla',
        }
    );
    return;
}

#========================================================================================
sub createRequest_positive_test {
    my $self = shift;
    my $SubTestName = ( caller(0) )[3];

    my $Client = $self->{'Client'};
    $Client->{'HttpClient'} = _mockHTTPClient( { 'post' => \&_assertPostCreatePaymentContent, } );

    my $hRequest;
    my $hMetadata;
    my $apikey = 'test_i7quwyd897y23we';

    $hMetadata->{guid} = '12355-654654-654847-54845';
    $hMetadata->{orderId} = 'order1';

    $hRequest->{amount}         = '120.32';
    $hRequest->{orderid}        = '12343';
    $hRequest->{description}    = 'mollie payment';
    $hRequest->{redirectUrl}    = 'www.myshop.com';
    $hRequest->{method}         = 'iDeal';
    $hRequest->{webhookUrl}     = 'www.myshop.com/callback';
    $hRequest->{locale}         = 'en_GB';
    $hRequest->{metadata}         = $hMetadata;

    # check url
    ## no critic (ProhibitPrivateSubroutineUse)
    like( $Client->createRequest($hRequest,$apikey)->{'paymentUrl'}, qr#https://www.mollie.com/paymentscreen/creditcard/#, "$SubTestName - post Payment URL OK" );

}

#========================================================================================
sub createRequest_negative_test {
    my $self = shift;
    my $SubTestName = ( caller(0) )[3];

    my $Client = $self->{'Client'};
    $Client->{'HttpClient'} = _mockHTTPClient( { 'post' => \&_assertPostCreatePaymentContent, } );

    my $hRequest;
    my $apikey = undef;

    $hRequest->{amount}         = undef;
    $hRequest->{orderid}        = '12343';
    $hRequest->{description}    = undef;
    $hRequest->{redirectUrl}    = undef;
    $hRequest->{method}         = undef;
    $hRequest->{webhookUrl}     = undef;
    $hRequest->{locale}         = undef;
    $hRequest->{metadata}       = undef;

    # check url
    ## no critic (ProhibitPrivateSubroutineUse)
    dies_ok( sub{$Client->createRequest($hRequest, $apikey)->{'paymentUrl'}}, "$SubTestName - Test Mandatory fields not set " );

}

#========================================================================================
sub _mockHTTPClient {
    my ($hMockMethods) = @_;
    my $mockRemote = Test::MockObject->new();
    $mockRemote->set_isa('DE_EPAGES::EPagesJ::API::Object::HTTPClient');
    $mockRemote->fake_module( 'DE_EPAGES::EPagesJ::API::Object::HTTPClient', %$hMockMethods );
    while ( my ( $method, $handler ) = each %$hMockMethods ) {
        $mockRemote->mock( $method, $handler );
    }
    return $mockRemote;
}

#========================================================================================
sub _assertPostCreatePaymentContent {
    shift;
    my ( $URL, $hHeader, $Content ) = @_;
    my $SubTestName = ( caller(0) )[3];

    ## no critic (ProhibitComplexRegexes)
    like( $URL, qr|^http://localhost:8088/rs/payments/mollie/payment.*|, "$SubTestName - URL" );

    return HTTP::Response->new( HTTP_OK, status_message(HTTP_OK), undef, <<'EOL'
       {
           "id":"tr_MU84QbtAms",
           "paymentUrl":"https://www.mollie.com/paymentscreen/creditcard/testmode/dc0aa798840b6cfacc203277df02174f"
       }
EOL
    );

}

__PACKAGE__->runScript;
