#========================================================================================
# package      DE_EPAGES::MolliePayments::API::MolliePaymentsClient
# state        public
# description  Service for Mollie
#========================================================================================
package DE_EPAGES::MolliePayments::API::MolliePaymentsClient;

use strict;

no warnings 'redefine'; ##no critic qw(ProhibitNoWarnings)

use DE_EPAGES::EPagesJ::API::Object::RestClient;
use DE_EPAGES::MolliePayments::API::Requests::RequestWrapper;

use constant BASE_URI =>  'payments/mollie/v2';

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Mollie::API::MolliePaymentsClient->new( %args );
#----------------------------------------------------------------------------------------
# description  Instantiates a new MolliePaymentsClient with Epagesj Rest client set.
#----------------------------------------------------------------------------------------
# input        $RequestObject | request object to handle | object
# return       MolliePaymentsClient | object | DE_EPAGES::MolliePayments::API::MolliePaymentsClient
#========================================================================================
sub new {
    my $class = shift;
    my ($RequestObject)  = @_;

    my $self  = bless {
        'request' => $RequestObject
    }, $class;

    return $self;
}

#========================================================================================
# function     withTestMode
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Client = DE_EPAGES::Mollie::API::MolliePaymentsClient->withTestMode( $IsTestMode );
#----------------------------------------------------------------------------------------
# description  Stores a variable in MolliePaymentsClient object.
#----------------------------------------------------------------------------------------
# input        $IsTestMode | true (1) or false (0) | integer
# return       $MolliePaymentsClient | MolliePaymentsClient object | DE_EPAGES::MolliePayments::API::MolliePaymentsClient
#========================================================================================
sub withTestMode {
    my $self = shift;
    my ($IsTestMode) = @_;

    $self->{'IsInTestMode'} = $IsTestMode ? 1 : 0;

    return $self;
}

#========================================================================================
# function     doPostRequest
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Response = $self->doPostRequest();
#----------------------------------------------------------------------------------------
# description  It calls (post) and retrieves the response information from epagesj
#               MolliePayments project and filters
#----------------------------------------------------------------------------------------
# return       $Response | filtered response hash | hash.ref
#========================================================================================
sub doPostRequest {
    my $self = shift;

    my $Request = $self->{'request'};
    my $RequestWrapper = $self->_createRequestWrapper($Request);
    my $DecodedResponse = $RequestWrapper->doPost($self->{'IsInTestMode'} );

    return $Request->handleResponse($DecodedResponse);
}

#========================================================================================
# function     doGetRequest
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Response = $self->doGetRequest();
#----------------------------------------------------------------------------------------
# description  It calls (get) and retrieves the response information from epagesj
#               MolliePayments project and filters
#----------------------------------------------------------------------------------------
# return       $Response | filtered response hash | hash.ref
#========================================================================================
sub doGetRequest {
    my $self = shift;

    my $Request = $self->{'request'};
    my $RequestWrapper = $self->_createRequestWrapper($Request);
    my $DecodedResponse = $RequestWrapper->doGet($self->{'IsInTestMode'} );

    return $Request->handleResponse($DecodedResponse);
}

#========================================================================================
# function     doGetRequest
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Response = $self->doGetRequest();
#----------------------------------------------------------------------------------------
# description  It calls (get) and retrieves the response information from epagesj
#               MolliePayments project and filters
#----------------------------------------------------------------------------------------
# return       $Response | filtered response hash | hash.ref
#========================================================================================
sub doDeleteRequest {
    my $self = shift;

    my $Request = $self->{'request'};
    my $RequestWrapper = $self->_createRequestWrapper($Request);
    my $DecodedResponse = $RequestWrapper->doDelete($self->{'IsInTestMode'} );

    return $Request->handleResponse($DecodedResponse);
}

#========================================================================================
# function     doPutRequest
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Response = $self->doPutRequest();
#----------------------------------------------------------------------------------------
# description  It calls (put) and retrieves the response information from epagesj
#               MolliePayments project and filters
#----------------------------------------------------------------------------------------
# return       $Response | filtered response hash | hash.ref
#========================================================================================
sub doPutRequest {
    my $self = shift;

    my $Request = $self->{'request'};
    my $RequestWrapper = $self->_createRequestWrapper($Request);
    my $DecodedResponse = $RequestWrapper->doPut($self->{'IsInTestMode'} );

    return $Request->handleResponse($DecodedResponse);
}

#----------------------------------------------------------------------------------------
# Private methods
#----------------------------------------------------------------------------------------
sub _createRequestWrapper() {
    my $self = shift;
    my ($Request) = @_;

    my $RequestWrapper = DE_EPAGES::MolliePayments::API::Requests::RequestWrapper->new($Request);
    return $RequestWrapper;

}

1;

