#========================================================================================
# package      DE_EPAGES::MolliePayments::t::unit::MolliePaymentsUrlBuilder
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::MolliePayments::API::MolliePaymentsUrlBuilder
#========================================================================================
package DE_EPAGES::MolliePayments::t::unit::UI_MolliePayments;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;

use Test::Exception;
use Test::MockObject::Extends;
use Test::More;

use strict;

use constant MBO_URL => 'https://unity-molliep.vm-hsilva.intern.epages.de/'.
    'epages/unity_molliep.admin/sec7585fa3953/?';
use constant MBO_QUERY => 'ViewAction=MBO-ViewSettings&ObjectID=22404';
use constant RESULT_URL => 'https://www.mollie.com/oauth2/authorize?';
use constant RESULT_QUERY => 'approval_prompt=force&'.
    'client_id=12345&'.
    'redirect_uri=https%3A%2F%2Fredirect_uri.de&'.
    'response_type=code&'.
    'scope=dsadasd+retertert&'.
    'state=https%3A%2F%2Funity-molliep.vm-hsilva.intern.epages.de%2F'.
    'epages%2Funity_molliep.admin%2Fsec7585fa3953%2F%3F'.
    'ViewAction%3DMBO-ViewSettings%26ObjectID%3D22404';

sub test {
    my $self = shift;

    $self->test_BuildConnectAndReconnectUrl();
    $self->test_BuildRedirectToMboUrl();

    done_testing();
}

#----------------------------------------------------------------------------------------
# Tests
#----------------------------------------------------------------------------------------
sub test_BuildConnectAndReconnectUrl {
    my $self        = shift;

    my $SUT = $self->_createSUT();
    my $actualResult = $SUT->buildConnectAndReconnectUrl(undef, MBO_URL. MBO_QUERY);

    like( $actualResult, qr(^${\RESULT_URL}), 'check Mollie URL scheme/authority/path part');

    my %actualQuery = URI::URL->new($actualResult)->query_form;
    my %expectedQuery = URI::URL->new(RESULT_URL. RESULT_QUERY)->query_form;
    is_deeply(\%actualQuery, \%expectedQuery, 'check Mollie URL query part');

    return;
}

sub test_BuildRedirectToMboUrl {
    my $self        = shift;

    my $SUT = $self->_createSUT();

    my $hQueryParameters = {
        'code' => 'authorization_code',
        'state' => [MBO_URL. MBO_QUERY]
    };
    my $actualResult = $SUT->buildRedirectToMboUrl($hQueryParameters);

    like( $actualResult, qr(^${\MBO_URL}), 'check MBO URL scheme/authority/path part');

    my %actualQuery = URI::URL->new($actualResult)->query_form;
    my %expectedQuery = URI::URL->new(MBO_URL. MBO_QUERY.'&code=authorization_code')->query_form;
    is_deeply(\%actualQuery, \%expectedQuery, 'check MBO URL query part');

    return;
}
#----------------------------------------------------------------------------------------
# Helpers
#----------------------------------------------------------------------------------------

sub _createSUT {
    my $self = shift;
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::MolliePayments::API::MolliePaymentsUrlBuilder');

    $Mockify->addMockWithReturnValueAndParameterCheck( '_buildQueryParameters', {
        'response_type'   => 'code',
        'client_id'       => 12345,
        'scope'           => 'dsadasd retertert',
        'redirect_uri'    => 'https://redirect_uri.de',
        'state'           => MBO_URL. MBO_QUERY,
        'approval_prompt' => 'force',
    }, [ {'string' => MBO_URL. MBO_QUERY} ]);


    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();
