#========================================================================================
# package      DE_EPAGES::Moneybookers::Hooks::Basket
# base         -
# state        public
# description  Hook Functions for basket
#========================================================================================
package DE_EPAGES::Moneybookers::Hooks::Basket;

use strict;
use warnings;
use DE_EPAGES::Core::API::Error qw (Error);
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::Address::API::Address qw (IsUnambiguousBasketAddress);

use DE_EPAGES::Moneybookers::API::Constants qw (@SKRILL_HIDDEN_PAYMENT_METHODS);

#========================================================================================
# function     OnUIBasket2Order_CheckAddress
# state        public
#----------------------------------------------------------------------------------------
# syntax        OnUIBasket2Order_CheckAddress($hParams);
#----------------------------------------------------------------------------------------
# description  When basket is changed function checks if error message need to be show.
#----------------------------------------------------------------------------------------
# input         $hParams | hash reference of input parameters | hash reference
# return        -
#========================================================================================
sub OnUIBasket2Order_CheckAddress {
    my ($hParams) = @_;
    my $Basket = $$hParams{'Basket'};
    my $Container = $Basket->container;
    return unless defined($Container);

    my $Payment = $Container->get('Payment');
    return unless defined($Payment);

    my $PaymentMethod = $Payment->get('PaymentMethod');
    return unless defined($PaymentMethod);

    my $Servlet = $$hParams{'Servlet'};
    my $ViewAction = $Servlet->form->value('ViewAction');
    return if(defined($ViewAction) && $ViewAction eq 'ViewAddress'); # do not perform error checks in first checkout step

    if ($PaymentMethod->class->alias eq 'PaymentMethodMoneybookers') {
            my $ShippingAddrError = 0;
            my $Address = $Basket->get('BillingAddress');
            if (defined $Address) {
                $ShippingAddrError = !IsUnambiguousBasketAddress($Basket);
            }
            if ($ShippingAddrError && ElementOf($PaymentMethod->get('SplitGatewayMethod'),
                                                @SKRILL_HIDDEN_PAYMENT_METHODS)) {
                $Servlet->vars('SkrillBillingAddressUpdated',1);
                Error( 'INVALID_FORM', { 'ViewVars', { 'FormError', 0 }, 'ViewAction', 'View' });
            }
    }
    return;
}

1;
