use strict;

use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::MultiStoreConnector::API::RestConnector;
use Getopt::Long;

sub Main {

    my ($Help, $CategoryIdStart, $CategoryIdStop, $MaxNumberProducts);
    GetOptions(
        'help'              => \$Help,
        'categoryIdStart=s' => \$CategoryIdStart,
        'categoryIdStop=s'  => \$CategoryIdStop,
        'products=s'        => \$MaxNumberProducts,
    );

    usage() if $Help;
    usage() unless $CategoryIdStart;
    usage() unless $CategoryIdStop;
    usage() unless $MaxNumberProducts;

    my $RestConnectorProducts = DE_EPAGES::MultiStoreConnector::API::RestConnector->new('http://skoenig-vm1.intern.epages.de:3000/products.json');
    my $RestConnectorProductCategories = DE_EPAGES::MultiStoreConnector::API::RestConnector->new('http://skoenig-vm1.intern.epages.de:3000/product_categories.json');

    my $ShopGUID = 1;
    my $Product;
    my $ProductCategory;
    for (my $CategoryId = $CategoryIdStart; $CategoryId <= $CategoryIdStop; $CategoryId++) {

        for (my $i = 1; $i <= $MaxNumberProducts; $i++) {
            $Product = {
                'product' => {
                    'GUID' => "$CategoryId-$i",
                    'Path' => "/ShopsMasterShop/Products/Product$CategoryId-$i",
                    'shop_id' => 1,
                    'Alias' => "Product$CategoryId-$i",
                    'Position' => $i
                }
            };

            my $Response = $RestConnectorProducts->createProduct($ShopGUID, $Product);
            my $ProductId = $Response->{'id'};

            $ProductCategory = {
                'product_category' => {
                    'product_id' => $ProductId,
                    'category_id' => $CategoryId
                }
            };
            $RestConnectorProductCategories->createProductCategory($ShopGUID, $ProductCategory);
        }
    }
}

sub usage {
    print <<END_USAGE;
Usage:
    perl $0 [options]

options:
    -products        Number of products per category (66)
    -categoryIdStart Id of the first category ()
    -categoryIdStop  Id of the last category ()

Example:
    perl $0 -products 66 -categoryIdStart 1 -categoryIdStop 100
END_USAGE
    exit 2;
}

RunScript( 'Sub' => \&Main );

1;
