#========================================================================================
# package      DE_EPAGES::MultiStoreMaster::Hooks::PreDefAttribute
# state        private
#========================================================================================
package DE_EPAGES::MultiStoreMaster::Hooks::PreDefAttribute;

use strict;

use DE_EPAGES::MultiStoreCommon::API::Synchronization qw( GetDefaultValues );
use DE_EPAGES::MultiStoreCommon::API::ObjectUpdate qw( InsertObjectUpdate TestObjectClass ); ##no critic qw(RequireCorrectImports)
use DE_EPAGES::Core::API::Log qw ( GetLog );

#========================================================================================
# function     OnInsertPreDefAttribute
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnInsertPreDefAttribute($hParams);
#----------------------------------------------------------------------------------------
# description  OBJ_InsertPreDefAttribute triggered
#               ProductType pre def attribute values have been added -> bookmark attribute for export
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Object - local object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnInsertPreDefAttribute {
    my ($hParams) = @_;

    _InsertOrUpdatePreDefAttribute($hParams->{'Object'});

    return;
}

#========================================================================================
# function     OnAfterUpdatePreDefAttribute
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnAfterUpdatePreDefAttribute($hParams);
#----------------------------------------------------------------------------------------
# description  OBJ_AfterUpdatePreDefAttribute triggered
#               ProductType pre def attribute values have been changed -> bookmark attribute for export
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Object - local object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnAfterUpdatePreDefAttribute {
    my ($hParams) = @_;

    _InsertOrUpdatePreDefAttribute($hParams->{'Object'});

    return;
}

#========================================================================================
# function     _InsertOrUpdatePreDefAttribute
# state        private
#----------------------------------------------------------------------------------------
# syntax       _InsertOrUpdatePreDefAttribute($Object);
#----------------------------------------------------------------------------------------
# description  Register Sync event for insert/update PreDefAttribute operation
#----------------------------------------------------------------------------------------
# input        $Object | PreDefAttribute object | object
#========================================================================================
sub _InsertOrUpdatePreDefAttribute {
    my ($Object) = @_;

    my $ClassName = TestObjectClass($Object, GetDefaultValues()->{'MASTER_CLASSES_LISTENED_TO'});
    return unless $ClassName;

    if ($ClassName eq 'PreDefAttribute') {
        InsertObjectUpdate($Object);
        $Object = $Object->get('Attribute');
    }

    InsertObjectUpdate($Object);
    InsertObjectUpdate($Object->get('AttributeClass'));

    return;
}

#========================================================================================
# function     OnDeletePreDefAttribute
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnDeletePreDefAttribute($hParams);
#----------------------------------------------------------------------------------------
# description  OBJ_DeletePreDefAttribute triggered
#               ProductType pre def attribute values have been deleted -> bookmark attribute for export
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Object - local object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnDeletePreDefAttribute {
    my ($hParams) = @_;

    my $Object = $hParams->{'Object'};

    GetLog('Devel')->debug($Object->get('ObjectID'));

    my $ClassName = TestObjectClass($Object, GetDefaultValues()->{'MASTER_CLASSES_LISTENED_TO'});
    return unless $ClassName;

    # $Object = $Object->get('Attribute');
    my $Attribute = $Object->get('Attribute');

    # Set 'Remove' flag for sync script.
    InsertObjectUpdate($Object, 1);
    InsertObjectUpdate($Attribute);
    InsertObjectUpdate($Attribute->get('AttributeClass'));

    return;
}

1;
