#========================================================================================
# package      DE_EPAGES::MultiStoreMaster::UI::Shop
# state        private
#========================================================================================
package DE_EPAGES::MultiStoreMaster::UI::Shop;
use base DE_EPAGES::Presentation::UI::Object;

use strict;
use HTTP::Status;

use DE_EPAGES::Core::API::Error qw( Error ExistsError GetError );
use DE_EPAGES::Core::API::String qw( QuoteXML );
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::MultiStoreCommon::API::Synchronization qw( GetDefaultValues );
use DE_EPAGES::MultiStoreMaster::API::AffiliateOverwritable qw( SetAffiliateOverwritableAttributes );
use DE_EPAGES::MultiStoreMaster::API::Basket qw( PullBasketFromSubShop );

sub PullBasket {
    my $self = shift;
    my ($Servlet) = @_;

    $self->BlockMonitor($Servlet);

    eval {
        my $RedirectURL = PullBasketFromSubShop( $Servlet, $Servlet->form->value('SubShopStore'), $Servlet->form->value('SubShopAlias'), $Servlet->form->value('BasketGUID') );

        my $Response = $Servlet->response;
        $Response->code(RC_SEE_OTHER);
        $Response->header( 'Location'     => $RedirectURL );
        $Response->header( 'Content-type' => 'text/html' );
        $Response->content( '<html><head><meta http-equiv="Refresh" content="0;URL=' . QuoteXML($RedirectURL) . '"/></head><body></body></html>' );
        $Servlet->vars( 'ExitAfterEvent', 1 );
    };
    if ( ExistsError() ) {
        my $Error = GetError();
        Error($Error);
    }

    return;
}

sub ViewSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $Shop = $Servlet->object;

    my @Values;
    my $hOAC = GetDefaultValues()->{'OVERWRITABLE_ATTRIBUTES'};
    my $hOverwritableAttributes = $Shop->get('MS_OverwritableAttributes');

    foreach my $Key ( keys %$hOAC ){
        my $aOA = $hOverwritableAttributes->{$Key};
        push @Values, {
            'ObjectType' => $Key,
            'Values' => [
                map {
                    { 'AttributeName' => $_, 'Value' => ElementOf($_, $aOA) }
                } @{ $hOAC->{$Key} }
            ]
        };
    }

    $Servlet->vars('OverwritableAttributes', \@Values);
    return;
}

sub Save {
    my $self = shift;
    my ($Servlet) = @_;
    my $Shop = $Servlet->object;

    my DE_EPAGES::Presentation::API::Form $Form = $Servlet->form;
    my $hValues = $Form->form($Shop, 'SaveAffiliateOverwritable');
    my $ClassOverwritableMap = {
        'Product' => [],
        'Category' => [],
    };
    while ( my ($Key, $Value) = each(%$hValues) ) {
        push (@{$ClassOverwritableMap->{$1}}, $2) if ($Value && $Key =~ /(Product|Category)(\w+)/);
    }

    foreach my $Key (keys %$ClassOverwritableMap){
        SetAffiliateOverwritableAttributes($Shop, $Key, $ClassOverwritableMap->{$Key});
    }
}

1;
