use strict;
use SOAP::Lite;
use URI;
use Time::HiRes qw (time);

my $Server = 'bweisse-vm3';
#my $Server = 'hmoye:8888';
my $Store  = 'Master';
my $Shop   = 'MasterShop';
my $Login  = 'admin';
my $Pass   = 'admin';

## no critic (ProhibitMagicNumbers)
my $MaximumProductUpdates = 2000;
my $updateOnlyStocklevelFactor = 0.8;       # 80% updates are only stocklevel changes

# Create a SOAP::Lite client object
my $ProductService = SOAP::Lite
    ->uri( 'urn://epages.de/WebService/ProductService/2011/10' )
    ->proxy( "http://$Server/epages/$Store.soap" )
    ->xmlschema('2001');

# Authentication
my $URI = URI->new( $ProductService->proxy->endpoint );
$URI->userinfo( "/Shops/$Shop/Users/$Login:$Pass" );
$ProductService->proxy->endpoint( $URI->as_string );


#start time tracking
my $time0 = time();


# find products
my $aResults = $ProductService->find()->result;
my $NumberOfProducts = $aResults ? scalar @$aResults : 0;
print "number of products: $NumberOfProducts\n";
my @ProductPaths = @$aResults;

#print needed time
printf "need %.1f seconds\n", time()-$time0;
$time0 = time();

#first tests with less products
$NumberOfProducts = $MaximumProductUpdates if $NumberOfProducts > $MaximumProductUpdates;


# get ALL info of Products in steps of 500 each
my $hProductsByPath = {};
my $offsetIndex = 499;
my $startIndex = 0;
while( $startIndex < $NumberOfProducts ) {

    my $lastIndex = $startIndex + $offsetIndex;
    $lastIndex = $NumberOfProducts-1 if ( $lastIndex > $NumberOfProducts-1 );
    my @ProductPathsSet = @ProductPaths[$startIndex..$lastIndex];

    print"getInfo($startIndex..$lastIndex)\n";
    $aResults = $ProductService->getInfo( \@ProductPathsSet )->result;

    # save infos for updates
    foreach my $hProduct ( @$aResults ) {
        $hProductsByPath->{$hProduct->{'Path'}} = {
            'StockLevel'    => $hProduct->{'StockLevel'},
            'ProductPrices' => $hProduct->{'ProductPrices'},
            'Text'          => $hProduct->{'Text'},
        }
    }

    $startIndex = $lastIndex + 1;
};
#print needed time
printf "need %.1f seconds more\n", time()-$time0;
$time0 = time();


#update stocklevel only for defined percentage of all products
my $lastUpdateIndex = int( $NumberOfProducts * $updateOnlyStocklevelFactor );

$startIndex = 0;
while( $startIndex < $lastUpdateIndex ) {

    my $lastIndex = $startIndex + $offsetIndex;
    $lastIndex = $lastUpdateIndex if ( $lastIndex > $lastUpdateIndex );
    #my @ProductPathsSet = @ProductPaths[$startIndex..$lastIndex];

    my $aUpdateProductsStocklevel = [];
    print"update($startIndex..$lastIndex)\n";
    foreach my $ProductPath ( @ProductPaths[$startIndex..$lastIndex] ) {

        #set stocklevel=1 or increase existing stocklevel
        my $StockLevel = 1;
        my $hProductData = $hProductsByPath->{$ProductPath};
        $StockLevel = $hProductData->{'StockLevel'}+1 if $hProductData->{'StockLevel'};

        push @$aUpdateProductsStocklevel, {
            'Path'          => $ProductPath,
            'StockLevel'    => $StockLevel,

            #pass also some unchanged data
            'ProductPrices'  => $hProductsByPath->{$ProductPath}->{'ProductPrices'},
            'Text'   =>  $hProductsByPath->{$ProductPath}->{'Text'},
        };
    }
    $aResults = $ProductService->update( $aUpdateProductsStocklevel )->result;

    $startIndex = $lastIndex + 1;
};
#print needed time
printf "need %.1f seconds more\n", time()-$time0;
$time0 = time();

