#========================================================================================
# package      DE_EPAGES::Ogone::Hooks::Servlet
# state        public
# description  Additional hook function for OnIsEp6HandledUnityRequest hook.
#========================================================================================
package DE_EPAGES::Ogone::Hooks::Servlet;

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

#========================================================================================
# function     OnIsEp6HandledUnityRequest
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnIsEp6HandledUnityRequest($hParams);
#----------------------------------------------------------------------------------------
# description  Triggered by hook IsEp6HandledUnityRequest.
#               The checkout process should be rendered by epages6 for any Unity shop.
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Object - servlet object</li>
#                   <li>Values - attributes</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnIsEp6HandledUnityRequest {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Object'};

    # skip if another hook function already acknowledges the request as a unity request handled by epages6
    return if $hParams->{'Values'}->{'IsEp6HandledUnityRequest'};

    my @ChangeActions = $Servlet->form->value('ChangeAction');
    if ( scalar @ChangeActions and
         ( ElementOf('PaymentBacklinkOgoneAmazon', @ChangeActions) or
           ElementOf('PaymentCallbackOgone', @ChangeActions) or
           ElementOf('OgonePBAS', @ChangeActions) or
           ElementOf('PaymentBacklinkOgoneAmazonStatus', @ChangeActions)
         )
        )
    {
        $hParams->{'Values'}->{'IsEp6HandledUnityRequest'} = 1;
        return;
    }

    return;

}

1;
