#========================================================================================
# package      DE_EPAGES::PayPalExpress::API:IconUrlLocalizer
# state        public
#----------------------------------------------------------------------------------------
# description  Provides function for localisation of icon url
#========================================================================================
package DE_EPAGES::PayPalExpress::API::IconUrlLocalizer;

use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::Object::API::Factory qw (LoadRootObject);
use DE_EPAGES::Object::API::Language qw ( GetPKeyLanguageByCode );
use DE_EPAGES::PayPalExpress::API::Constants qw ( PAYPALEXPRESS_ICON_SILVER PAYPALEXPRESS_ICON_GOLD );
use strict;

#========================================================================================
# function     new
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Localizer = new DE_EPAGES::Object::API::IconUrlLocalizer;
#----------------------------------------------------------------------------------------
# description  create a new localizer
#----------------------------------------------------------------------------------------
# return       $Localizer | blessed object | object
#========================================================================================
sub new { bless {}, shift; }

sub getPayPalExpressIconUrl {
    my $self = shift;
    my ($Basket, $PaymentMethod) = @_;

    my $LineItemContainer = $Basket->container();
    my $System = $self->_LoadRootObject();

    my $LanguageID = $LineItemContainer->get('LanguageID');
    my $LanguageGerman = $self->_GetPKeyLanguageByCode('de');
    if($LanguageID == $LanguageGerman) {
        my $StoreRoot = sprintf('%s%s',$System->get('ProtocolAndServerSSL'), $System->get('StoreRoot'));

        if($PaymentMethod->get('IsPayPalExpressButtonSilver')) {
            return sprintf('%s%s', $StoreRoot, PAYPALEXPRESS_ICON_SILVER);
        } else {
            return sprintf('%s%s', $StoreRoot, PAYPALEXPRESS_ICON_GOLD);
        }
    } else {
        my $LocaleID = $LineItemContainer->get('LocaleID');
        return $self->_localizePayPalExpressButtonURL($System->get('PayPalExpress_CheckoutButtonURL'), $LocaleID);
    }

    return;
}

sub _localizePayPalExpressButtonURL {
    my $self = shift;
    my ($Url, $LocaleID) = @_;

    # list of by PayPal supported button locales
    my @LocaleIDs = qw( de_DE en_US fr_FR it_IT es_ES nl_NL );
    $LocaleID = 'en_US' unless ElementOf($LocaleID, @LocaleIDs);

    $Url =~ s/\[\[locale\]\]/$LocaleID/eg;
    return $Url;
}

sub _LoadRootObject {
    my $self = shift;
    return LoadRootObject();
}

#========================================================================================
# function     _GetPKeyLanguageByCode
# state        private
#----------------------------------------------------------------------------------------
# syntax       $LanguageID = _GetPKeyLanguageByCode($LanguageCode);
#----------------------------------------------------------------------------------------
# description  Wrapper for unit test. Returns the Language id (primary key) by providing
#               associated language code2.
#----------------------------------------------------------------------------------------
# input        $LanguageCode | language code2 | string
# return       $LanguageID | language id (primary key) | integer
#========================================================================================
sub _GetPKeyLanguageByCode {
    my $self = shift;
    my ($LanguageCode) = @_;

    return GetPKeyLanguageByCode($LanguageCode);
}

1;
