#==============================================================================
# package      DE_EPAGES::PayPalExpress::Hooks::OrderProcess
# state        private
#==============================================================================
package DE_EPAGES::PayPalExpress::Hooks::OrderProcess;

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::ExternalPayment::API::Constants qw (DEFAULT_PAYMENT_STEP_POSITION);

#========================================================================================
# function     OnRegisterCheckoutProcess
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnRegisterCheckoutProcess($hParams);
#----------------------------------------------------------------------------------------
# description  register payment step for checkout process
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Servlet - servlet - object</li>
#                   <li>BasketOrderProcess - basket order process - object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnRegisterCheckoutProcess {
    my ($hParams) = @_;

    my $Servlet = $hParams->{'Servlet'};
    my $BasketOrderProcess = $hParams->{'BasketOrderProcess'};

    my $BasketOrder = $Servlet->object;
    my $Container = $BasketOrder->container;
    return unless defined $Container;

    my $pli = $Container->get('Payment');
    return unless defined($pli);
    return unless ($pli->instanceOf('LineItemPaymentPayPalExpress'));

    # return if we come from a callback (see UI::Basket::PayPalExpressReturn)
    my $APIStep = $pli->get('Field1');
    return if defined $APIStep and ElementOf($APIStep, qw(DoExpressCheckoutPayment CheckoutRequestDetails));

    $BasketOrderProcess->addStep('PayPalExpress', DEFAULT_PAYMENT_STEP_POSITION);
    return;
}

#========================================================================================
# function     AfterRegisterCheckoutProcess
# state        public
#----------------------------------------------------------------------------------------
# syntax       AfterRegisterCheckoutProcess($hParams);
#----------------------------------------------------------------------------------------
# description  set order step; remove payment step if necessary
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Servlet - servlet - object</li>
#                   <li>BasketOrderProcess - basket order process - object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub AfterRegisterCheckoutProcess {
    my ($hParams) = @_;

    my $Servlet = $hParams->{'Servlet'};
    my $BasketOrderProcess = $hParams->{'BasketOrderProcess'};

    my $BasketOrder = $Servlet->object;
    my $Container = $BasketOrder->container;
    return unless defined $Container;

    my $pli = $Container->get('Payment');
    return unless defined $pli;

    if ($pli->instanceOf('LineItemPaymentPayPalExpress')) {
        my $APIStep = $pli->get('Field1');
        unless (defined $APIStep and
                ElementOf($APIStep, qw(DoExpressCheckoutPayment CheckoutRequestDetails))) {
            if ($pli->get('PaymentMethod')->get('DoPaymentOnBasket')) {
                $BasketOrderProcess->setOrderStep('PayPalExpress');
            }
        }
    }
    else {
        $BasketOrderProcess->deleteStep('PayPalExpress');
    }

    return;
}

1;
