#========================================================================================
# package      DE_EPAGES::PayPalExpress::Hooks::Servlet
# state        public
# description  Additional hook function for OnIsEp6HandledUnityRequest hook.
#========================================================================================
package DE_EPAGES::PayPalExpress::Hooks::Servlet;

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

#========================================================================================
# function     OnIsEp6HandledUnityRequest
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnIsEp6HandledUnityRequest($hParams);
#----------------------------------------------------------------------------------------
# description  Triggered by hook IsEp6HandledUnityRequest.
#               The checkout process should be rendered by epages6 for any Unity shop.
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Object - servlet object</li>
#                   <li>Values - attributes</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnIsEp6HandledUnityRequest {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Object'};

    # skip if another hook function already acknowledges the request as a unity request handled by epages6
    return if $hParams->{'Values'}->{'IsEp6HandledUnityRequest'};

    my @ChangeActions = $Servlet->form->value('ChangeAction');
    my @ChangeActionsHandledByEpages6 = qw(
        PayPalExpressIPN PayPalExpressGiroPaySuccess PayPalExpressGiroPayCancel
        PayPalExpressReturn PayPalExpressCancel PayPalExpressCancelOnOrder
        Refund PayPalExpress PayPalExpressCallback
    );

    foreach my $ChangeActionHandledByEpages6 (@ChangeActionsHandledByEpages6){
        if (scalar @ChangeActions and
            ElementOf($ChangeActionHandledByEpages6, @ChangeActions)) {
            $hParams->{'Values'}->{'IsEp6HandledUnityRequest'} = 1;
            return;
        }
    }

    my $aViewActionsHandledByEp6 = [
        'UnityViewSFPayPalExpressFailed'
    ];
    my $ViewAction = $Servlet->params('ViewAction');

    if (ElementOf($ViewAction, $aViewActionsHandledByEp6)) {
        $hParams->{'Values'}->{'IsEp6HandledUnityRequest'} = 1;
    }

    return;
}

1;
