#==============================================================================
# package      DE_EPAGES::Presentation::API::TLE::GUI::AccordionHandler
# base         DE_EPAGES::Presentation::API::TLE::GUIObject
# description  Handler to build and work with jquery accordions in the templates
# state        public
#==============================================================================
package DE_EPAGES::Presentation::API::TLE::GUI::AccordionHandler;
use base DE_EPAGES::Presentation::API::TLE::GUIObject;

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

#==============================================================================
# function     new
# state        public
#------------------------------------------------------------------------------
# syntax       $Handler = DE_EPAGES::Presentation::API::TLE::GUI::AccordionHandler->new($Processor);
# example      my $Handler  = DE_EPAGES::Presentation::API::TLE::GUI::AccordionHandler->new($Processor);
#------------------------------------------------------------------------------
# description  Creates a new handler.
#------------------------------------------------------------------------------
# input        $Processor | processor | object
#------------------------------------------------------------------------------
# return       $Handler | blessed object | object
#==============================================================================
sub new {
    my $class = shift;
    my ($Processor) = @_;

    my $self = $class->SUPER::new($Processor);

    $self->{'TemplateVars'}->{'Items'} = [];
    $self->{'TemplateVars'}->{'ItemExpanded'} = 0;
    $self->{'TemplateVars'}->{'TagName'} = 'div';
    $self->{'TemplateName'} = 'AccordionHandler';
    $self->{'Options'} = {};

    return $self;
}

sub RegisterGUIHandler {
    my ($hParams) = @_;

    $hParams->{'GUIHandler'}->registerGUIObject(__PACKAGE__,'accordion');
}

#==============================================================================
# function     tag
# state        public
#------------------------------------------------------------------------------
# syntax       #Accordion.tag(Param)
# example      #Accordion.tag("div") or #Accordion.tag("span")
#------------------------------------------------------------------------------
# description  setup the tag name of the accordion container node.
#------------------------------------------------------------------------------
# input        Param | tag-name | string
#==============================================================================
sub tag {
    my $self = shift;
    my ($Param) = @_;

    $self->{'TemplateVars'}->{'TagName'} = lc $Param;

    return;
}

#==============================================================================
# function     item
# state        public
#------------------------------------------------------------------------------
# syntax       #Accordion.item(Params)
#------------------------------------------------------------------------------
# example      #Accordion.item("content" = "the content", "title"="My title")
#------------------------------------------------------------------------------
# description  Adds a new item.
#------------------------------------------------------------------------------
# input        Params | list of attributes, e.g. HTML-attributes except "class",
#               #Accordion.item("open" = 1) to show on default| string list
#==============================================================================
sub item {
    my $self = shift;
    my (%Params) = @_;

    $Params{'TemplateFileContext'} = $self->{'Processor'}->getContext()->{'TemplateFileName'};
    push @{$self->{'TemplateVars'}->{'Items'}}, \%Params;

    if( $Params{'open'} ){
        $self->{'TemplateVars'}->{'ItemExpanded'} = scalar(@{$self->{'TemplateVars'}->{'Items'}}) - 1;
    }

    return;
}

#==============================================================================
# function     option
# state        public
#------------------------------------------------------------------------------
# syntax       #Accordion.option(Params)
#------------------------------------------------------------------------------
# example      #Accordion.option("collapsable" = "true")
#------------------------------------------------------------------------------
# description  Sets jQuery UI accordion options.
#------------------------------------------------------------------------------
# input        Params | list of options, see jQuery UI accordion options |
#                        hash.string
#==============================================================================
sub option {
    my $self = shift;
    my (%Params) = @_;

    # List of allowed accordion options.
    my $aWhiteList = ['collapsible'];

    # ToDo: Check valid accordion options: http://api.jqueryui.com/accordion
    %Params = map { $_ => $Params{$_} } grep { ElementOf($_, $aWhiteList) } keys %Params;
    $self->{'TemplateVars'}->{'Options'} = \%Params;

    return;
}

1;
