#!perl -w
use Test::More tests => 5;
use strict;
use Data::Dumper;

use DE_EPAGES::Core::API::File qw ( CreateDirectory );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::SystemCommand qw( SystemCommand );
use DE_EPAGES::Database::API::Config qw( StoreType );
use DE_EPAGES::Presentation::API::Ctmpls qw( FindPrivateTemplates );
use DE_EPAGES::XML::API::XML::CartridgeInstallerImportHandler qw(GetStoreTypeCartridges);

sub Main {
    local $| = 1;

  SKIP: {
      skip("skipping Ctmpl.t on $^O", 5) if $^O eq 'MSWin32';

      my $CartridgesBaseDir = '/srv/epages/eproot/Cartridges';
      my $CartridgesTestDir = $CartridgesBaseDir. '/.test';
      my $Product = "$CartridgesTestDir/DE_EPAGES/Product";
      my $Order = "$CartridgesTestDir/DE_EPAGES/Order";
      my $PrivTmpl = 'Data/Private/Templates/DE_EPAGES';

      #generate clean test dir
      SystemCommand("rm -rf $CartridgesTestDir", {Print => 1});
      CreateDirectory($CartridgesTestDir);

      #copy all files under $EPAGES_CARTRIDGES to test dir
      foreach my $File (qw(Cartridges.xml DE_EPAGES)) {
          SystemCommand("cp -rl $CartridgesBaseDir/$File $CartridgesTestDir", {Print => 1});
      }

      #create directory /srv/epages/eproot/Cartridges/.test/DE_EPAGES/Product/Data/Private/Templates/DE_EPAGES
      CreateDirectory("$Product/$PrivTmpl");
      SystemCommand("cp -rl $Product/Templates $Product/$PrivTmpl/Product", {Print => 1});

      CreateDirectory("$Order/$PrivTmpl");
      SystemCommand("cp -rl $Product/Templates $Order/$PrivTmpl/Order", {Print => 1});

      # original /srv/epages/eproot/Cartridges should not have private templates
      my $Expected = 0;
      my $hasPrivateTemplates = FindPrivateTemplates('Store');
      my $Found = scalar keys %$hasPrivateTemplates;

      #quick and dirty multistore handling
      foreach my $Cartridge (keys %$hasPrivateTemplates){
          # ignore cartridges not in DE_EPAGES
          $Expected += 1 if $hasPrivateTemplates->{$Cartridge} !~ m,Cartridges/DE_EPAGES/,;
          # ignore DE_EPAGES/MultiStore cartridges
          $Expected += 1 if $hasPrivateTemplates->{$Cartridge} =~ m,Cartridges/DE_EPAGES/MultiStore,;
      }
      ok( $Found == $Expected, 'FindPrivateTemplates(Store)' )
          or Test::More::diag Dumper($hasPrivateTemplates);

      # we added private templates for DE_EPAGES::Product
      $hasPrivateTemplates = FindPrivateTemplates('Store', undef,
                                                  ['DE_EPAGES::Product'],
                                                  [$CartridgesTestDir]);
      is_deeply( $hasPrivateTemplates,
                 { 'DE_EPAGES/Product' => "$Product/$PrivTmpl/Product" },
                 'FindPrivateTemplates(Store, undef, [DE_EPAGES::Product],...)'
      ) or Test::More::diag Dumper($hasPrivateTemplates);

      $hasPrivateTemplates = FindPrivateTemplates(undef, 'Store',
                                                  ['DE_EPAGES::Product'],
                                                  [$CartridgesTestDir]);
      is_deeply( $hasPrivateTemplates,
                 { 'DE_EPAGES/Product' => "$Product/$PrivTmpl/Product" },
                 'FindPrivateTemplates(undef, Store, [DE_EPAGES::Product],...)'
      ) or Test::More::diag Dumper($hasPrivateTemplates);

      # we added private templates for DE_EPAGES::Order
      $hasPrivateTemplates = FindPrivateTemplates('Store', undef,
                                                  ['DE_EPAGES::Product', 'DE_EPAGES::Order'],
                                                  [$CartridgesTestDir]);
      is_deeply( $hasPrivateTemplates,
                 { 'DE_EPAGES/Product' => "$Product/$PrivTmpl/Product",
                   'DE_EPAGES/Order' => "$Order/$PrivTmpl/Order",
                 },
                 'FindPrivateTemplates(...,[DE_EPAGES::Product, DE_EPAGES::Order],...)'
      ) or Test::More::diag Dumper($hasPrivateTemplates);

      # if private templates for DE_EPAGES::Dictionary are added
      SystemCommand("cp -rl $Product/Templates $Order/$PrivTmpl/Dictionary");

      $hasPrivateTemplates = FindPrivateTemplates('Store', undef, undef,
                                                  [$CartridgesTestDir]);
      # then all cartridges have private templates
      $Expected = scalar @{GetStoreTypeCartridges(StoreType('Store'))};
      $Found = scalar keys %$hasPrivateTemplates;
      ok( $Found == $Expected, 'FindPrivateTemplates(...,[DE_EPAGES::Dictionary],...)' )
          or Test::More::diag Dumper($hasPrivateTemplates);

      # clean up
      SystemCommand("rm -rf $CartridgesTestDir", {Print => 1});
    }
}

RunScript(Sub=>\&Main);
1;
