#========================================================================================
# package      DE_EPAGES::Product::API::Resource::ProductCategories
# state        public
# base         DE_EPAGES::WebService::API::Resource::BaseObjectResource
# description  implements the REST resource for product-categories.
#========================================================================================
package DE_EPAGES::Product::API::Resource::ProductCategories;
use base DE_EPAGES::WebService::API::Resource::BaseObjectResource;

use DE_EPAGES::Core::API::Url qw (ParseQueryString);
use DE_EPAGES::Object::API::Factory qw (LoadObjectByPath);
use DE_EPAGES::Object::API::Object::Locale;
use DE_EPAGES::Shop::API::Resource::ShopRequestContext;
use DE_EPAGES::Shop::API::Resource::Formatter;
use DE_EPAGES::Product::API::Resource::CustomAttributes;
use DE_EPAGES::Product::API::Resource::ProductSlideshow;
use DE_EPAGES::Product::API::Resource::ProductVariation;
use DE_EPAGES::Product::API::Resource::ProductLowestPrice;

use strict;

no warnings 'redefine'; ##no critic qw(ProhibitNoWarnings)

sub service {
    return LoadObjectByPath('/RestServices/ProductCategories');
}



sub class {
    return 'Product';
}



sub producedContentTypes {
    shift;
    my ($RequestMethod) = @_;

    return {
        GET => [
            ['get', 'application/vnd.epages.v1+json'],
            ['get', 'application/json'],
        ],
    }->{$RequestMethod};
}



sub match {
    my $self = shift;
    my ($Request) = @_;

    return unless $Request->uri->path =~ m|^/api/products/([^/]+)/categories/?$|;

    return $1;
}



sub params {
    my $self = shift;
    my ($ActionName, $Object, $Request) = @_;

    if ( $ActionName eq 'get' ) {
        my $hQuery = ParseQueryString( $Request->uri->query, 'utf-8' );
        my $LocaleID = $hQuery->{'locale'}->[0];
        return [ $Object, $LocaleID ];
    } else {
        return [ $Object ];
    }
}



sub href {
    my $self = shift;
    my ($APIBaseURL, $ProductGUID) = @_;
    return "$APIBaseURL/api/categories/?productId=$ProductGUID";
}



sub hrefToCategory {
    my $self = shift;
    my ( $APIBaseURL, $GUID ) = @_;
    return "$APIBaseURL/api/categories/$GUID";
}



sub get {
    my $self = shift;
    my ($Product, $LocaleID) = @_;

    my $Shop = $Product->getSite;
    my $Context = DE_EPAGES::Shop::API::Resource::ShopRequestContext->new($Shop);

    $LocaleID = $Context->validLocale($LocaleID);
    my $Locale= DE_EPAGES::Object::API::Object::Locale->load($LocaleID);
    my $LanguageID = $Locale->get('LanguageID');

    my $APIBaseURL = $Context->apiBaseUrl();

    my @Attributes = qw(
        GUID
        Categories
        NameOrAlias
    );
    my $hProduct = $Product->getWithParent(\@Attributes, $LanguageID);

    my $hResult = {};

    # add a link to self.
    push @{$hResult->{'links'}}, {
        rel => 'self',
        title => undef,
        href => $self->href($APIBaseURL, $Product->guid),
    };

    # add a link to product.
    my $ProductResourceHref = DE_EPAGES::Product::API::Resource::Product->new()->href($APIBaseURL, $Product->guid);
    push @{$hResult->{'links'}}, {
        rel => 'product',
        title => $hProduct->{'NameOrAlias'},
        href => $ProductResourceHref,
    };

    # add links of categories
    foreach my $category (@{$hProduct->{'Categories'}}){
        push @{$hResult->{'links'}}, {
            rel => 'category',
            title => $category->get('NameOrAlias', $LanguageID),
            href => $self->hrefToCategory($APIBaseURL, $category->guid),
        };
    }

    return $hResult;
}

1;
