#==================================================================================================
# package      DE_EPAGES::SIA::t::unit::Sale
# state        public
#--------------------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::SIA::API::Request::Sale
#==================================================================================================
package DE_EPAGES::SIA::t::unit::Sale;
use base DE_EPAGES::Core::API::Test;
use DE_EPAGES::SIA::API::Object::LineItemPaymentSIA;
use DE_EPAGES::SIA::t::unit::MockupObjects  qw (CreateMockedLineItemPayment
                                                TEST_MERCHANT_FUC
                                                CreateMockedServlet
                                                TEST_TERMINAL_NUMBER
                                                TEST_TRANS_ID
                                                TEST_REMOTE_ADDRESS);
use DE_EPAGES::SIA::API::Constants          qw (WINDOW_NAME
                                                SALE_EVENT_NAME
                                                PROTOCOL_VERSION);
use Test::More;
use strict;

## no critic qw(ProhibitMagicNumbers ProhibitCascadingIfElse)
sub test {
    my $self = shift;

    my $MockedLineItemPaymentSIA = CreateMockedLineItemPayment();
    my $Servlet                  = CreateMockedServlet();
    $Servlet->vars('IsMobile', 1);

    $self->test_getPaymentSalesRequest($MockedLineItemPaymentSIA);
    $self->test_getPaymentSalesRequest($MockedLineItemPaymentSIA, $Servlet);

    done_testing();
}

sub test_getPaymentSalesRequest {
    my $self = shift;
    my ($MockedLineItemPaymentSIA, $Servlet) = @_;

    my $aRequestData = $MockedLineItemPaymentSIA->getPaymentSalesRequest()->getRequestData($Servlet);

    ## no critic qw(ProhibitLongLines)
    foreach my $hRequestSaleData (@{$aRequestData}) {
        my $Field = $hRequestSaleData->{'Field'};
        if ($Field eq 'sNombreEvento') {
            $self->testField($Field,$hRequestSaleData, SALE_EVENT_NAME);
        }
        elsif ($Field eq 'sIdWindow') {
            $self->testField($Field,$hRequestSaleData, WINDOW_NAME);
        }
        elsif ($Field eq 'IDVERSION') {
            $self->testField($Field,$hRequestSaleData, PROTOCOL_VERSION);
        }
        elsif ($Field eq 'IDTERMINAL') {
            $self->testField($Field,$hRequestSaleData, TEST_TERMINAL_NUMBER);
        }
        elsif ($Field eq 'IDENTIDAD') {
            $self->testField($Field,$hRequestSaleData, 'ACEN');
        }
        elsif ($Field eq 'IDCOMERCIO') {
            $self->testField($Field,$hRequestSaleData, TEST_MERCHANT_FUC);
        }
        elsif ($Field eq 'IDSERVICIO') {
            $self->testField($Field,$hRequestSaleData,  '');
        }
        elsif ($Field eq 'IDUSUARIO') {
            $self->testField($Field,$hRequestSaleData,'');
        }
        elsif ($Field eq 'IDTM') {
            $self->testField($Field,$hRequestSaleData,'1200');
        }
        elsif ($Field eq 'OPCTOKEN') {
            $self->testField($Field,$hRequestSaleData,'01');
        }
        elsif ($Field eq 'IDPEDIDO') {
            $self->testField($Field,$hRequestSaleData,TEST_TRANS_ID);
        }
        elsif ($Field eq 'NOMTITULAR') {
            $self->testField($Field,$hRequestSaleData,'Test User');
        }
        elsif ($Field eq 'CODPAIS') {
            $self->testField($Field,$hRequestSaleData,'276');
        }
        elsif ($Field eq 'PAN') {
            $self->testField($Field,$hRequestSaleData,'');
        }
        elsif ($Field eq 'FECCAD') {
            $self->testField($Field,$hRequestSaleData,'');
        }
        elsif ($Field eq 'CVC') {
            $self->testField($Field,$hRequestSaleData,'');
        }
        elsif ($Field eq 'IMPTRANS') {
            $self->testField($Field,$hRequestSaleData,'8000');
        }
        elsif ($Field eq 'CODMON') {
            $self->testField($Field,$hRequestSaleData,'978');
        }
        elsif ($Field eq 'TIMETRANS') {
            # do not test datetime functionality
        }
        elsif ($Field eq 'IDIOMA') {
            $self->testField($Field,$hRequestSaleData,'de');
        }
        elsif ($Field eq 'IPORIGEN') {
            $self->testField($Field,$hRequestSaleData,TEST_REMOTE_ADDRESS);
        }
        elsif ($Field eq 'FIRMTOKEN') {
            # TODO: Activate test for firm token.
            #$self->testEncryptionToken($hRequestSaleData, 'todo');
        }
        elsif ($Field eq 'TOKEN') {
            $self->testField($Field,$hRequestSaleData,'');
        }
        elsif ($Field eq 'DESTOKEN') {
            $self->testField($Field,$hRequestSaleData,'');
        }
        elsif ($Field eq 'URLOK') {
            if (defined($Servlet) && $Servlet->vars('IsMobile')) {
                $self->testField(
                    $Field,
                    $hRequestSaleData,
                    'http://unit-test.epages.de/epages/UnitTestShop.mobile/'.
                    '?ChangeAction=PaymentBacklinkSuccessSIA&ObjectID=12345&OrderID=15917&ViewAction=MobileSF-View');
            }
            else {
                $self->testField(
                    $Field,
                    $hRequestSaleData,
                    'http://unit-test.epages.de/epages/UnitTestShop.sf/'.
                    '?ChangeAction=PaymentBacklinkSuccessSIA&ObjectID=12345&OrderID=15917');
            }
        }
        elsif ($Field eq 'URLKO') {
            if (defined($Servlet) && $Servlet->vars('IsMobile')) {
                $self->testField(
                    $Field,
                    $hRequestSaleData,
                    'http://unit-test.epages.de/epages/UnitTestShop.mobile/'.
                    '?ChangeAction=PaymentBacklinkErrorSIA&ObjectID=12345&OrderID=15917&ViewAction=MobileSF-View');
            }
            else {
                $self->testField(
                    $Field,
                    $hRequestSaleData,
                    'http://unit-test.epages.de/epages/UnitTestShop.sf/'.
                    '?ChangeAction=PaymentBacklinkErrorSIA&ObjectID=12345&OrderID=15917');
            }
        }
        elsif ($Field eq 'EMAILUSUARIO') {
            $self->testField($Field,$hRequestSaleData,'test@epages.de');
        }
        else {
            ok(0,'unknown field: '.$Field);
        }
    }
    return;
}

sub testField {
    my $self = shift;
    my ($FieldName,$hData,$ExpectedValue) = @_;

    is($hData->{'Field'},$FieldName                 ,'EventName - '.$FieldName.'Field');
    is($hData->{'Value'},$ExpectedValue             ,'EventName - '.$FieldName.'Value');

    return;
}

__PACKAGE__->runScript();

1;
