#==============================================================================
# package      DE_EPAGES::SageRestConnector::UI::Shop
# state        private
#==============================================================================
package DE_EPAGES::SageRestConnector::UI::Shop;
use base DE_EPAGES::Presentation::UI::Object;

use strict;

use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::AppStore::API::Constants qw( APPSTORE_APP_TYPES );
use DE_EPAGES::SageRestConnector::API::Constants qw ( SageOmniSellerAppID );

use JSON;



sub UnityViewSageRestConnector {
    my $self = shift;
    my ($Servlet) = @_;

    my $AppsClient = DE_EPAGES::AppStore::API::Object::AppsClient->create(
        {
            'Shop'   => $Servlet->object,
            'Locale' => $Servlet->locale
        }
    );

    my $hParams = {};
    $hParams->{'resultsPerPage'} = 1000;

    my $Apps = $AppsClient->listApps( 1, APPSTORE_APP_TYPES, undef, undef, $hParams);

    # get all installed apps
    my $aInstalledApps = $AppsClient->myApps();
    my @InstalledAppIDs;
    push @InstalledAppIDs, $_->{'id'} foreach @$aInstalledApps;

    # set up JSON parser
    my $json = JSON->new;
    # allow blessed objects to avoid errors
    $json = $json->allow_blessed;
    # enable pretty JSON output
    $json = $json->pretty;

    my $hInfo;
    foreach my $hApp (@{$Apps->{'content'}}){
        if ($hApp->{'id'} eq SageOmniSellerAppID){
            $hInfo = $hApp;
            if (ElementOf($hApp->{'id'}, @InstalledAppIDs)) {
                $hInfo->{'installed'} = JSON::true;
            } else {
                $hInfo->{'installed'} = JSON::false;
            }
            $Servlet->vars( 'AppData', $hInfo);
            $Servlet->vars( 'AppDataJSON', $json->encode($hInfo));
            last;
        }
    }
}

1;
