#==============================================================================
# package      DE_EPAGES::ShopConfiguration::UI::FeaturePack
# state        private
#==============================================================================
package DE_EPAGES::ShopConfiguration::UI::FeaturePack;
use base DE_EPAGES::ShopConfiguration::UI::FeatureCollection;

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::Object::API::Factory qw( LoadClassByAlias );

sub NewObject {
    my $self = shift;
    my ($Servlet) = @_;

    my $Parent = $Servlet->object->folder('FeaturePacks');
    my $Class = LoadClassByAlias('FeaturePack');

    return  $self->SUPER::NewObject( $Servlet, $Parent, $Class );
}


sub Save {
    my $self = shift;
    my ($Servlet) = @_;
    my $FeaturePack = $Servlet->object;
    my $Form = $Servlet->form;

    $self->SUPER::Save($Servlet);

    # save the shop association for the featurepack
    my $hValues = $Form->form($FeaturePack, 'FeaturePackShops');

    my @ShopTypeIDs = map {$_->{'ShopTypeID'}} @{$hValues->{'ShopTypes'}};
    my $ProviderShopTypes = $Servlet->object->get('Provider')->shopTypes;
    foreach my $ProviderShoptype (@{$ProviderShopTypes}) {
        if ( ElementOf($ProviderShoptype->id, @ShopTypeIDs) ){
            $ProviderShoptype->addFeaturePack($FeaturePack) unless $ProviderShoptype->hasFeaturePack($FeaturePack);
        }else {
            $ProviderShoptype->removeFeaturePack($FeaturePack) if $ProviderShoptype->hasFeaturePack($FeaturePack);
        }
    }

    return;
}

sub Delete {
    my $self = shift;
    my ($Servlet) = @_;

    my $Provider = $Servlet->object;
    my $Form = $Servlet->form;

    my $hValues = $Form->form($Provider, 'DeleteFeaturePack');
    my @FeaturePackIDs = map { $_->{'FeaturePackID'} } @{$hValues->{'FeaturePacks'}};
    my $aFeaturePacks = $Provider->loadObjects( \@FeaturePackIDs, 'FeaturePack' );

    # delete only if accepted if confirmation is used
    if (scalar @$aFeaturePacks and $Servlet->user->get('DeleteConfirmation') and not $Servlet->params('ACCEPT')) {
        $Servlet->vars('DeleteObjects', [ map { $_->tleHash } @$aFeaturePacks]);
        $Servlet->vars('DELETE',1);
        return;
    } else {
        # else reset delete
        $Servlet->vars('DELETE',0);
    }

    # test if exists active SFCollections and display an error if exists
    foreach my $FeaturePack (@$aFeaturePacks) {

        my $SFCollections  = $FeaturePack->get('ActiveShopRefs');

        if (@{$SFCollections}){
            # Error if SFCollections exists
            $Servlet->form->addFormError({
                'Reason'=> 'FeaturePack_ExistsOnShops',
                'Form'  => 'Delete',
                'Name'  => 'FeaturePackID',
            });
        }else {
            $FeaturePack->delete;
        }
    }

    # delete the FP
    $Servlet->form->executeFormError;

    return;
}

1;
