use DE_EPAGES::Core::API::Error qw( ExistsError GetError );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::Warning qw( Warning );
use DE_EPAGES::Database::API::Connection qw( RunOnStore );
use DE_EPAGES::Object::API::Factory qw( LoadRootObject );
use DE_EPAGES::ShopMigration::API::MigrationShop qw( SetShopFeatureValues );
use DE_EPAGES::Shop::API::Feature qw ( ExistsFeatureByAlias );
use DE_EPAGES::WebInterface::API::MessageCenter qw( SynchronizeCache );
use Getopt::Long;
use strict;

RunScript( 'Sub' => \&Main, 'Message'  =>'long' );

sub Main {
    local $| = 1;

    my %Options = ();
    my @GetOpt = qw(help passwd=s storename=s shop=s feature=s maxvalue=s);
    usage("Unkown parameter specified.\n") unless GetOptions(\%Options, @GetOpt);
    usage() if $Options{help};
    for (qw(storename shop feature maxvalue)) {
        usage(sprintf('Missing parameter -%s', $_)) unless defined $Options{$_};
    }
    my $ShopAlias    = $Options{shop};
    my $FeatureAlias = $Options{feature};
    my $MaxValue     = $Options{maxvalue};

    RunOnStore(
        Store => $Options{storename},
        Sub => sub  {
            usage(sprintf('Unknown feature: %s', $FeatureAlias)) unless ExistsFeatureByAlias($FeatureAlias);
            my $ShopFolderAlias = $ShopAlias =~ /prep/ ? 'PrepShops' : 'Shops';
            my $ShopFolder = LoadRootObject()->child($ShopFolderAlias);
            usage(sprintf('No such shop: %s', $ShopAlias)) unless $ShopFolder->existsChild($ShopAlias);
            my $Shop = $ShopFolder->child($ShopAlias);
            printf "Setting %s -> %s for shop %s\n", $FeatureAlias, $MaxValue, $ShopAlias;
            SetShopFeatureValues($Shop, [ { Alias => $FeatureAlias, MaxValue => $MaxValue } ]);
        },
    );
    eval { SynchronizeCache(); };
    Warning( GetError() ) if ExistsError();
}

sub usage {
    my ($ErrorNote) = @_;

    print STDERR "\n$ErrorNote\n\n" if $ErrorNote;
    print <<END_USAGE;
Description
  This scripts sets a single shop feature to a given MaxValue. Can also be used to unset features.
  Note: Those values are reverted on global apply (e.g. PBO/Scripts/Post-Patch)!

Usage:
    perl $0 [options] flags objects

options:
    -passwd      database user password                                    ()
    -shop        shop alias                                                required
    -storename   name of store                                             required
    -feature     feature alias                                             required
    -maxvalue    use this for MaxValue for feature                         required

flags:
    -help        show the command line options                             ()

Example:
    perl $0 -storename Store -shop MyShop -feature ProductCustomization -maxvalue 0
    perl $0 -storename Store -shop MyShop -feature ProductTypes -maxvalue 100
END_USAGE
    exit 2;
}
