#==============================================================================
# package      DE_EPAGES::ShopNewsletter::API::NewsletterCampaign
# state        public
# description  Returns template snippets for the newsletter.
#==============================================================================
package DE_EPAGES::ShopNewsletter::API::NewsletterCampaign;
use base Exporter;

use strict;
use DE_EPAGES::Core::API::Error qw (Error ExistsError GetError);
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

our @EXPORT_OK = qw (
    AddCustomersAndUsers
);

#========================================================================================
# function     AddCustomersAndUsers
# state        public
#----------------------------------------------------------------------------------------
# syntax       AddCustomersAndUsers($Form, $NewsletterCampaign, $hObjectIDs )
#----------------------------------------------------------------------------------------
# description  Add users and customers to a newsletter campaign.
#----------------------------------------------------------------------------------------
# input        $Form                     | form object     | object
# input        $NewsletterCampaign       | newsletter campaign object | object
# input        $hObjects     | coupon condition objects
#                                 <ul>
#                                   <li>Customers - list of customers - ref.array</li>
#                                   <li>Users - list of users - ref.array</li>
#                                 </ul> | ref.hash
# input        $hParams | optional flags
#                            <ul>
#                              <li>NoFormError - do not handle form errors
#                                              - boolean (default 0)
#                              </li>
#                            </ul> | ref.hash
#========================================================================================
sub AddCustomersAndUsers {
    my ($Form, $NewsletterCampaign, $hObjects, $hParams) = @_;

    $hParams->{'NoFormError'} //= 0;

    foreach my $Customer (@{$hObjects->{'Customers'}}) {
        eval { $NewsletterCampaign->addCustomer($Customer) };
        if (!$hParams->{'NoFormError'} && ExistsError()) {
            my $Error = GetError();
            Error($Error) unless ElementOf($Error->code, qw(
                NumberOfAddresseesExceeded
                EMailFromTrayInAddresseeList
                InsertNotSuccessful
                NoEMail
                FORMAT_NOT_EMAILADDRESS
            ));
            $Form->mapFormError({'Name' => 'AddCustomer'}, $Error);
        }
    }
    foreach my $User (@{$hObjects->{'Users'}}){
        eval { $NewsletterCampaign->addUser($User) };
        if(!$hParams->{'NoFormError'} && ExistsError()) {
            my $Error = GetError();
            Error($Error) unless  ElementOf($Error->code, qw(
                NumberOfAddresseesExceeded
                EMailFromTrayInAddresseeList
                InsertNotSuccessful
                NoEMail
                FORMAT_NOT_EMAILADDRESS
            ));
            $Form->mapFormError({'Name' => 'AddUser'}, $Error);
        }
    }
    $Form->executeFormError;

    return;
}

1;
