#========================================================================================
# package      DE_EPAGES::ShopNewsletter::Hooks::Basket
# state        public
# description  Hook module for newsletter.
#========================================================================================
package DE_EPAGES::ShopNewsletter::Hooks::Basket;

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::Newsletter::UI::Site;

#========================================================================================
# function     OnAfterSaveCustomerData
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnAfterSaveCustomerData( $hParams );
#----------------------------------------------------------------------------------------
# description  Get selected and filtered by not subscribed newsletters and send the
#               customer an confirmation request email. Sets always Unsubscribed=0.
#               (Hook UI_AfterSaveCustomerData)
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Servlet - servlet</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnAfterSaveCustomerData {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};
    my $User = $Servlet->user;

    my $IsAnonymous = $User->get('IsAnonymous');
    my $Shop = $Servlet->object->getSite();
    my $EMail = $IsAnonymous ? $Servlet->form->value('EMail') : $User->get('EMail');
    my $FirstName = $Servlet->form->value('FirstName');
    my $LastName = $Servlet->form->value('LastName');

    # there has to be an email and a name, either trough a registered user or filled in input fields
    return unless defined $EMail && (!$IsAnonymous || (defined $FirstName && defined $LastName));

    # load the selected and filtered newsletters
    my @NewsletterCampaigns = @{$Shop->get('NewsletterCampaigns')};
    my @FilteredCampaignsIDs = $Servlet->params('FilteredCampaignsIDs');
    my @SelectedCampaigns = grep { ElementOf($_->id, @FilteredCampaignsIDs) } @NewsletterCampaigns;

    return unless scalar @SelectedCampaigns;

    my $Name = $IsAnonymous ? $FirstName . ' ' . $LastName : $User->get('Name');
    my $UnSubscribe = 0;
    my $NewsletterUIPackage = DE_EPAGES::Newsletter::UI::Site->new({'Servlet'} => $Servlet);
    $NewsletterUIPackage->SendConfirmationRequestMail($Servlet, $Name, $EMail, $UnSubscribe, \@SelectedCampaigns);
    $Servlet->params('VERIFY_NEWSLETTER_EMAIL', 1) unless $Servlet->params('SEND_MAIL_FAILED');

    return;
}

1;
