#==============================================================================
# package      DE_EPAGES::ShopNewsletter::UI::JSON
# state        private
#==============================================================================
package DE_EPAGES::ShopNewsletter::UI::JSON;
use base DE_EPAGES::Presentation::UI::JSON;

use strict;

use DE_EPAGES::ShopNewsletter::API::NewsletterCampaign qw ( AddCustomersAndUsers );
use DE_EPAGES::Object::API::Factory qw (LoadClassByAlias);
use DE_EPAGES::ShopNewsletter::API::Newsletter qw(
    AddUnsubscribe
    InsertCouponSnippet
    AddProductsAndCatalogs
    AddShopLogo
);

#==============================================================================
# Event handlers
#==============================================================================
sub JSONAddSnippet {
    my $self = shift;
    my ($Servlet)  = @_;
    my $Form = $Servlet->form;
    my $FunctionName = $Form->value('FunctionName');

    my $Newsletter = $Servlet->object;
    my $Shop = $Newsletter->getSite();

    my $IsHtml = $Newsletter->get('IsHTML');
    my $LanguageID = $Newsletter->get('NewsletterCampaign')->get('LangID') || $Shop->get('LanguageID');

    if(defined $FunctionName and $FunctionName ne '') {
        my $Snippet;
        if ($FunctionName eq 'AddShopLogo') {
            $Snippet = AddShopLogo($Newsletter, $LanguageID, $IsHtml);
        }
        elsif ($FunctionName eq 'AddUnsubscribe') {
            $Snippet = AddUnsubscribe($Newsletter, $LanguageID, $IsHtml);
        }
        elsif ($FunctionName eq 'InsertCouponSnippet') {
            $Snippet = InsertCouponSnippet($Newsletter, $LanguageID, $IsHtml);
        }
        elsif ($FunctionName eq 'AddProductsAndCatalogsListFromTray') {
            my $Tray = DE_EPAGES::Presentation::API::Object::Tray->load($Servlet->intSessionID);
            my $aProducts = $Tray->objectsByClass(LoadClassByAlias('Product'));
            my $aCategories = $Tray->objectsByClass(LoadClassByAlias('Category'));
            $Snippet = AddProductsAndCatalogs($Newsletter, $LanguageID, $IsHtml, $aProducts, $aCategories);
        }
        else {
            $Servlet->form->executeFormError({
                'Name'      => 'AddSnippet',
                'Reason'    => 'UnknownSnippet',
            });
        }
        my %Info = ( 'snippet' => $Snippet, );
        $self->writeContentOutput(\%Info);
    }
    return;
}

sub JSONInsertCustomersAndUsers {
    my $self = shift;
    my ($Servlet) = @_;

    my $NewsletterCampaign = $Servlet->object;
    my $Shop = $NewsletterCampaign->getSite;
    my $Form = $Servlet->form;

    AddCustomersAndUsers($Form, $NewsletterCampaign, {
        'Customers' => $Shop->loadObjects([$Form->value('CustomerIDs')], 'Customer'),
        'Users'     => $Shop->loadObjects([$Form->value('UserIDs')], 'User'),
    }, {'NoFormError' => 1});
    return;
}

sub JSONInsertProductsAndCatalogs {
    my $self = shift;
    my ($Servlet) = @_;

    my $Newsletter = $Servlet->object;
    my $Form = $Servlet->form;

    my $Shop = $Newsletter->getSite();

    my $IsHtml = $Newsletter->get('IsHTML');
    my $LanguageID = $Newsletter->get('NewsletterCampaign')->get('LangID') || $Shop->get('LanguageID');

    my $aCategories = $Shop->loadObjects([$Form->value('CategoryIDs')], 'Category');
    my $aProducts = $Shop->loadObjects([$Form->value('ProductIDs')], 'Product');

    my $Snippet = AddProductsAndCatalogs($Newsletter, $LanguageID, $IsHtml, $aProducts, $aCategories, $Servlet->isSecureConnection());

    $self->writeContentOutput( { 'snippet' => $Snippet } );
}

1;
