#========================================================================================
# package      DE_EPAGES::Spreedly::API::Object::PaymentMethodSpreedlyTest
# state        public
# base         DE_EPAGES::Spreedly::API::Object::PaymentMethodSpreedly
#----------------------------------------------------------------------------------------
# description  object interface for Payment.
#========================================================================================
package DE_EPAGES::Spreedly::API::Object::PaymentMethodSpreedlyTest;
use base DE_EPAGES::Spreedly::API::Object::PaymentMethodSpreedly;

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );

use constant FEATURE_NAME => 'Spreedly';

use constant SUPPORTED_CURRENCIES_TEST => (qw(
    EUR
    GBP
    USD
));


#========================================================================================
# function     canAddToBasket
# state        public
#----------------------------------------------------------------------------------------
# syntax       if ($PaymentMethod->canAddToBasket($hVars)) {...
#----------------------------------------------------------------------------------------
# description  Tests if a payment method can be added to the basket with the given currency.
#               Overrides function <function DE_EPAGES::Order::API::Object::ContainerPaymentMethod::canAddToBasket>
#               Valid currencies are: EUR, GBP, USD
#----------------------------------------------------------------------------------------
# input        $hVars | <ul>
#                   <li>CurrencyID    - alpha currency code (ISO 4217) - char(3)
#                   <li>TaxModel      - gross or net price    - int
#               </ul> | ref.hash
# return       $canAddToBasket | true if payment method can be used for the given currency | boolean
#========================================================================================
sub canAddToBasket {
    my $self = shift;
    my ($hVars) = @_;

    my $AreCurrenciesSupported = ElementOf($hVars->{'CurrencyID'}, SUPPORTED_CURRENCIES_TEST);
    my $CanBeAddedToBasket = $AreCurrenciesSupported && $self->SUPER::canAddToBasket($hVars);

    return $CanBeAddedToBasket;
}

#========================================================================================
# function     default
# state        private
#----------------------------------------------------------------------------------------
# syntax       $hValues = DE_EPAGES::Spreedly::API::Object::PaymentMethodSpreedlyTest->default( $Parent, $hInfo );
# example      $hDefaults = $Class->defaultAttributes($Parent, $hInfo); # for insert a new object
#               $hDefaults = $Object->class->defaultAttributes($Object->parent, $hValues); # for an existing object
#----------------------------------------------------------------------------------------
# description  Returns default attribute values for new objects.
#               Used by <function DE_EPAGES::Object::Object::Class::defaultAttributes>
#----------------------------------------------------------------------------------------
# input        $Parent | parent object of the new object | object
# input        $hInfo | attribute name => value hash (passed to insert()) | ref.hash
# return       $hValues | hash with default attribute values (name => value) | ref.hash
#========================================================================================
sub default {
    my $class = shift;
    my ($Parent, $hInfo) = @_;

    return {
        %{$class->SUPER::default($Parent, $hInfo)}
    };
}

#========================================================================================
# function     featureName
# state        public
#----------------------------------------------------------------------------------------
# syntax       $FeatureName = $PaymentMethod->featureName;
#----------------------------------------------------------------------------------------
# description  Returns feature name.
#----------------------------------------------------------------------------------------
# return       $FeatureName | feature name (undef means no feature count) | String
#========================================================================================
sub featureName () { return FEATURE_NAME; }

1;
