#========================================================================================
# package      DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyMercadoPago
# base         DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly
# state        private
#----------------------------------------------------------------------------------------
# description  UI Controller for PaymentMethodSpreedlyMercadoPago
#========================================================================================
package DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyMercadoPago;
use base DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly;

use strict;

no warnings 'redefine'; ##no critic qw(ProhibitNoWarnings)

use DE_EPAGES::Core::API::PerlTools qw ( isValid );

use constant PAYMENT_TYPE_MERCADO_PAGO => 'SpreedlyMercadoPago';

#========================================================================================
# function     SaveSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       SaveSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to save settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub SaveSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $Form = $Servlet->form();
    my $Country = $Form->value('Country');
    my $AccessToken = $Form->value('AccessToken');

    if (isValid($Country) && isValid($AccessToken)) {
        $self->_createGateway($Country, $AccessToken, $Servlet);
    }

    my $PaymentMethod = $Servlet->object();
    $Form->form($PaymentMethod, 'SpreedlyMercadoPagoSettings');

    $self->SUPER::SaveSettings($Servlet);

}

#---------------------------------------------------------------------------
#  Private methods
#---------------------------------------------------------------------------
sub _createGateway {
    my $self = shift;
    my ($Country, $AccessToken, $Servlet) = @_;

    my $hAdditionalBodyParams = {
        'country' => $Country,
        'access_token' => $AccessToken
    };

    my $PaymentMethodSpreedly = DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly->new();
    $PaymentMethodSpreedly->SaveCredentials($Servlet, PAYMENT_TYPE_MERCADO_PAGO, $hAdditionalBodyParams);

    return;
}

1;
