#========================================================================================
# package      DE_EPAGES::Test::API::HtmlStructure
# base         DE_EPAGES::Test::API::TemplateTest
# state        public
#----------------------------------------------------------------------------------------
# description  Tests if the number of starting div tags equals the the number of ending
#               div tags per template file.
#========================================================================================
package DE_EPAGES::Test::API::HtmlStructure;
use base DE_EPAGES::Test::API::TemplateTest;

use strict;
use HTML::Parser;
use Test::More;

use DE_EPAGES::Core::API::File  qw ( GetFileContent GetFileContentLines ExistsFile );
use DE_EPAGES::Core::API::PerlTools  qw ( ElementOf trim );
use DE_EPAGES::Test::API::TemplateUtil  qw ( CleanContentForTesting );

sub test {
    my $self = shift;

    my @TemplateFiles = $self->getAllTemplateFiles();

    plan tests => scalar @TemplateFiles;

    foreach my $TemplateFile (@TemplateFiles) {
        _DivUsageTest($TemplateFile);
    }
}

sub getAllTemplateFiles {
    my $self = shift;

    my @TemplateFiles = $self->SUPER::getAllTemplateFiles();

    my $BlacklistFilename = join '', join('/', $ENV{'EPAGES_CARTRIDGES'}, 'DE_EPAGES', 'Test', 'API', 'HtmlStructureBlacklist'), $self->storeType, '.txt';

    my $aBlacklistedFiles = ExistsFile($BlacklistFilename) ? GetFileContentLines($BlacklistFilename) : [];
    $aBlacklistedFiles = [ map { trim join('/', $ENV{'EPAGES_CARTRIDGES'}, $_) } (@$aBlacklistedFiles) ];

    return ( grep { not ElementOf($_, $aBlacklistedFiles) } (@TemplateFiles) );
}

sub _DivUsageTest {
    my ($TemplateFile) = @_;

    my $rContent = GetFileContent($TemplateFile);
    my $CleanContent = CleanContentForTesting($$rContent);
    my $DivCounter = 0;

    my $Parser = HTML::Parser->new();
    $Parser->handler('start' => sub { $DivCounter++ if $_[0] eq 'div' }, 'tagname');
    $Parser->handler('end' => sub { $DivCounter-- if $_[0] eq 'div' }, 'tagname');
    $Parser->parse($CleanContent);

    is($DivCounter, 0, "$TemplateFile: all div's correct");
}


1;
