#========================================================================================
# package      DE_EPAGES::Twenga::API::Tools
# state        public
#----------------------------------------------------------------------------------------
# description  This package provides commong Twenga tooling.
#========================================================================================
package DE_EPAGES::Twenga::API::Tools;
use base qw( Exporter );

use strict;
use DE_EPAGES::Core::API::PerlTools qw ( ElementOf );
use DE_EPAGES::Twenga::API::Constants qw ( @VALID_COUNTRY_CODES );

our @EXPORT_OK = qw (   IsValidHex32
                        ValidTwengaCountries
                        IsValidTwengaCountry );


#========================================================================================
# function     IsValidHex32
# state        public
#----------------------------------------------------------------------------------------
# syntax       $result = IsValidHex32($str);
# example      if( IsValidHex32($str) ) { }
#----------------------------------------------------------------------------------------
# description  validates if string is hexadecimal and 32 characters long
#----------------------------------------------------------------------------------------
# input        $str | Hexadecimal 32 chars long string | string
# return       $result | boolean
#========================================================================================
sub IsValidHex32 {
    my ($hex32string) = @_;

    return ($hex32string =~ /^[0-9a-f]{32}$/i)? 1 : 0;
}

#========================================================================================
# function     ValidTwengaCountries
# state        public
#----------------------------------------------------------------------------------------
# syntax       $aCountryCodes = ValidTwengaCountries();
# example      my $aCountryCodes = ValidTwengaCountries();
#----------------------------------------------------------------------------------------
# description  returns an array with the valid countries (code2) for Twenga
#----------------------------------------------------------------------------------------
# return       $aCountryCodes | ref array
#========================================================================================
sub ValidTwengaCountries {

    return \@VALID_COUNTRY_CODES;
}

#========================================================================================
# function     IsValidTwengaCountry
# state        public
#----------------------------------------------------------------------------------------
# syntax       $result = IsValidTwengaCountry($countryCode);
# example      if( IsValidTwengaCountry($countryCode) ) { }
#----------------------------------------------------------------------------------------
# description  validates a country code2 as valid country for Twenga
#----------------------------------------------------------------------------------------
# input        $countryCode | country code2 | string
# return       $result | boolean
#========================================================================================
sub IsValidTwengaCountry {
    my ($code) = @_;

    my $validCodes = ValidTwengaCountries();
    return ElementOf($code, $validCodes);
}

1;
