#========================================================================================
# package      DE_EPAGES::WebService::t::unit::CodecFormUrlencoded
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::WebService::API::Codec::FormUrlencoded
#========================================================================================
package DE_EPAGES::WebService::t::unit::CodecFormUrlencoded;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Core::API::PerlTools qw( ElementOf );
use DE_EPAGES::Core::API::Url qw( ParseQueryString );
use DE_EPAGES::WebService::API::Codec::FormUrlencoded;
use HTTP::Message;
use HTTP::Headers;
use Test::More;

use strict;



sub test {
    my $self = shift;

    $self->test_contentType();
    $self->test_encode();
    $self->test_decode();

    done_testing();
}



sub test_contentType {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Codec = DE_EPAGES::WebService::API::Codec::FormUrlencoded->new();

    is($Codec->contentType(), 'application/x-www-form-urlencoded', "$SubTestName - test if the correct content-type is returned.");
}



sub test_encode {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Codec = DE_EPAGES::WebService::API::Codec::FormUrlencoded->new();

    my $hData = {
        'key' => 'value',
        'msg' => ['hello', 'world'],
        'numbers' => [1,2,3],
        'visible' => 'true',
    };
    my $Message = HTTP::Message->new();
    $Codec->encode($Message, $hData);

    my $hURL = ParseQueryString($Message->content(), 'utf-8');
    foreach my $Name (qw(key visible)) {
        is($hURL->{$Name}[0], $hData->{$Name}, "scalar $Name in query part" );
    }
    foreach my $Name (qw(msg numbers)) {
        foreach my $Value (@{$hData->{$Name}}) {
            ok(ElementOf($Value, $hURL->{$Name}), "array $Name elem $Value in query part" );
        }
    }
    is($Message->content_type, 'application/x-www-form-urlencoded', "$SubTestName - test if the correct content-type is returned.");
}



sub test_decode {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Codec = DE_EPAGES::WebService::API::Codec::FormUrlencoded->new();

    my $String = 'msg=hello&msg=world&visible=true&numbers=1&numbers=2&numbers=3&key=value';
    my $Headers = HTTP::Headers->new();
    $Headers->header('Content-Length' => 1);
    my $Message = HTTP::Message->new($Headers, $String );
    my $hHash = $Codec->decode($Message);

    my $hExpectedData = {
        'key' => 'value',
        'msg' => ['hello', 'world'],
        'numbers' => [1,2,3],
        'visible' => 'true',
    };
    is_deeply($hHash, $hExpectedData, "$SubTestName - test if string was decoded correctly.");
}

__PACKAGE__->runScript();
