#========================================================================================
# package      DE_EPAGES::WebService::t::unit::CodecJSON
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::WebService::API::Codec::JSON
#========================================================================================
package DE_EPAGES::WebService::t::unit::CodecJSON;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::WebService::API::Codec::JSON;
use HTTP::Message;
use HTTP::Headers;
use Test::More;
use JSON qw(from_json to_json);

use strict;

use constant JSON_TEXT => '{"msg":["hello","world"],"visible":true,"numbers":[1,2,3],"key":"value"}';

use constant DATA_HASH => { 'key' => 'value', 'msg' => ['hello', 'world'],
                            'numbers' => [1,2,3], 'visible' => JSON::XS::true };

sub test {
    my $self = shift;

    $self->test_contentType();
    $self->test_encode();
    $self->test_decode();

    done_testing();
}



sub test_contentType {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Codec = DE_EPAGES::WebService::API::Codec::JSON->new();

    is($Codec->contentType(),
       'application/json', "$SubTestName - test if the correct content-type is returned.");
}



sub test_encode {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Codec = DE_EPAGES::WebService::API::Codec::JSON->new();

    my $Message = HTTP::Message->new();
    $Codec->encode($Message, DATA_HASH);

    is(join('', sort map { s/,//g; $_ }
            split(/\n/, to_json(from_json($Message->content()), {pretty => 1}))),
       join('', sort map { s/,//g; $_ }
            split(/\n/, to_json(from_json(JSON_TEXT), {pretty => 1}))),
       "$SubTestName - test if hashref was encoded correctly.");
    is($Message->content_type, 'application/json',
       "$SubTestName - test if the correct content-type is returned.");
}



sub test_decode {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Codec = DE_EPAGES::WebService::API::Codec::JSON->new();

    my $Headers = HTTP::Headers->new();
    $Headers->header('Content-Length' => 1);
    my $Message = HTTP::Message->new($Headers, JSON_TEXT);

    is_deeply($Codec->decode($Message), DATA_HASH,
              "$SubTestName - test if string was decoded correctly.");
}

__PACKAGE__->runScript();
